Package: RcmdrPlugin.UCA
Type: Package
Title: UCA Rcmdr Plug-in
Version: 5.1-4
Date: 2026-05-04
Authors@R: person(given = "Manuel",
   family = "Munoz-Marquez",
   role = c("aut", "cre"),
   email = "manuel.munoz@uca.es")
Depends: IQCC, qcc, qicharts2, randtests, rmarkdown, TeachingDemos,
        tseries
Suggests: car, carData, knitr
VignetteBuilder: knitr
Imports: Rcmdr (>= 1.6)
Description: Some extensions to Rcmdr (R Commander), randomness test, 
 variance test for one normal sample and predictions using active model, 
 made by R-UCA project and used in teaching statistics at University of Cadiz (UCA).
License: GPL (>= 3)
URL: http://knuth.uca.es/RcmdrPlugin.UCA/
NeedsCompilation: no
Packaged: 2026-05-03 16:30:11 UTC; mmarquez
Author: Manuel Munoz-Marquez [aut, cre]
Maintainer: Manuel Munoz-Marquez <manuel.munoz@uca.es>
Repository: CRAN
Date/Publication: 2026-05-03 17:10:02 UTC
Built: R 4.6.0; ; 2026-05-03 19:58:15 UTC; unix

import('IQCC')
#import("pwr")
import('qcc')
import("Rcmdr")
# The next package is required to build vignettes
import("rmarkdown")

importFrom("qicharts2", "paretochart")
importFrom("randtests", randtest.runs.test = "runs.test")
importFrom("utils", "browseURL")
importFrom("TeachingDemos", "sigma.test")
importFrom("tcltk", "tkbutton")
importFrom("tseries", tseries.runs.test = "runs.test")

### Models
export("input2predict")
export("predict4dataset")

### Quality control
export("cchart1Menu")
export("cchart2Menu")
export("cchartpMenu")
export("npchart1Menu")
export("npchart2Menu")
export("npchartpMenu")
export("paretochartMenu")
export("pchart1Menu")
export("pchart2Menu")
export("pchartpMenu")
export("R1mcMenu")
export("R2mcMenu")
export("RpmcMenu")
export("S1mcMenu")
export("S2mcMenu")
export("SpmcMenu")
export("uchart1Menu")
export("uchart2Menu")
export("uchartpMenu")
export("xbar1mcMenu")
export("xbar2mcMenu")
export("xbarpmcMenu")
export("xbarone1Menu")

### Statistics
export("randomnessFTest")
export("randomnessNTest")
export("twolevelfactor.runs.test")
export("SampleSizeZMenu")
export("sigmaTest")
export("numeric.runs.test")

### Help
export("browseRUCAWebsite")
export("browseRcmdrPluginUCA")
export("checkRUCAversion")

# Example of randomness test for a numeric variable
# Load data "sweetpotato" selecting from Rcmdr menu:
# "Data" -> "Data in packages" -> "Read data set from an attached package..."
# then double-click on "randtests", click on "sweetpotato" and on "OK".
# Rcmdr reply with the following command in source pane (R Script)
data(sweetpotato, package="randtests")
sweetpotato <- as.data.frame(sweetpotato)
# To make randomness test on variable "yield", select from Rcmdr menu:
# "Statistics" -> "Nonparametric tests" -> "Randomness test for numeric variable..."
# select "yield" and "OK"
# Rcmdr reply with the following command in source pane (R Script)
with(sweetpotato, numeric.runs.test(yield))
#	Runs Test
# data:  yield
# statistic = -4.5751, runs = 17, n1 = 35, n2 = 35, n = 70, p-value = 0.000004759
# alternative hypothesis: nonrandomness

# Example of "Add predictions to existing dataset..."
# Load data "Chile" selecting from Rcmdr menu:
# "Data" -> "Data in packages" -> "Read data set from an attached package..."
# then double-click on "car", click on "Chile" and "OK".
# Rcmdr reply with the following command in source pane (R Script)
data(Chile, package="car")
# To build a model select from Rcmdr menu:
# "Statistics" -> "Model fit" -> "Linear Regresion..."
# As "Variable explicada" select income and age as "Variables explicativas" and click on "OK"
# Rcmdr reply with the following command in source pane (R Script)
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
# Note that the active model is set to RegModel.1
# So if you want to predict the values for income for age data in Chile dataset
# Select from Rcmdr menu:
# "Models" -> "Predict using active model" -> "Add predictions to existing dataset..."
# In the dialog select a compatible dataset with the model
# In this case select Chile
# Rcmdr reply with the following command in source pane (R Script)
Chile$fitted <- predict(RegModel.1, Chile)
# The predicted value of income has been saved as fitted in the selected dataset (Chile)

# Example of test and confidence interval of sigma for one normal population
# Load data "sweetpotato" selecting from Rcmdr menu:
# "Data" -> "Data in packages" -> "Read data set from an attached package..."
# then double-click on "randtests", click on "sweetpotato" and on "OK".
# Rcmdr reply with the following command in source pane (R Script)
data(sweetpotato, package="randtests")
sweetpotato <- as.data.frame(sweetpotato)
# To make test and confidence interval for sigma var from variable "yield", select from Rcmdr menu:
# "Statistics" -> "Nonparametric tests" -> "Single-sample Chi-square-test..."
# select "yield" and "OK"
# Rcmdr reply with the following command in source pane (R Script)
with(sweetpotato, sigma.test(yield[!is.na(yield)], alternative='two.sided', sigmasq=1.0, conf.level=0.95))
#	One sample Chi-squared test for variance
# data:  yield[!is.na(yield)]
# X-squared = 6514.8, df = 69, p-value < 2.2e-16
# alternative hypothesis: true variance is not equal to 1
# 95 percent confidence interval:
#   69.41231 135.93966
# sample estimates:
# var of yield[!is.na(yield)] 
#                    94.41731 

# Ejemplo de test de aleatoriedad para un factor con dos niveles
# Cargar los datos "AMSsurvey" eligiendo del menu de Rcmdr:
# "Datos" -> "Conjuntos de datos en paquetes" -> "Leer conjunto de datos desde paquete adjunto..."
# pulsar dos veces sobre "car", pulsar sobre "AMSsurvey" y sobre "Aceptar".
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
data(AMSsurvey, package="carData")
# Para hacer el test de aleatoriead para la variable "sex", elegir del menu de Rcmdr:
# "Estadisticos"-> "Test no parametricos"-> "Test de aleatoriedad para un factor de dos niveles..."
# Elegir "sex" y "Aceptar"
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
with(AMSsurvey, twolevelfactor.runs.test(sex))
#	Runs Test
# data:  sex
# Standard Normal = 4.5917, p-value = 0.000004397
# alternative hypothesis: two.sided

# Example of "Input data and predict"
# Load data "Chile" selecting from Rcmdr menu:
# "Data" -> "Data in packages" -> "Read data set from an attached package..."
# then double-click on "car", click on "Chile" and on "OK".
# Rcmdr reply with the following command in source pane (R Script)
data(Chile, package="carData")
# To build a model select from Rcmdr menu:
# "Statistics" -> "Model fit" -> "Linear Regresion..."
# As "Response variable" select income and age as "Explanatory variables" and click on "OK"
# Rcmdr reply with the following command in source pane (R Script)
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
# Note that the active model is set to RegModel.1
# So if you want to predict a new value for a 35 and 40 age person
# Select from Rcmdr menu:
# "Models" -> "Predict using active model" -> "Input data and predict"
# In age column input 35 and 40 and then close the editor.
# Rcmdr reply with the following command in source pane (R Script)
.data <- edit(data.frame(age = numeric(0)))
.data
predict(RegModel.1, .data)
remove(.data)
# And output the predicted value of income for that age using active model (RegModel.1)

# Ejemplo de "Anadir predicciones a un conjunto de datos existente..."
# Cargar los datos "Chile" eligiendo del menu de Rcmdr:
# "Datos" -> "Conjuntos de datos en paquetes" -> "Leer conjunto de datos desde paquete adjunto..."
# pulsar dos veces sobre "car", pulsar sobre "Chile" y "Aceptar".
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
data(Chile, package="car")
# Para construir un modelo seleccione del menu de Rcmdr:
# "Estadisticos" -> "Ajuste de modelos" -> "Regresion lineal..."
# Como "Variable explicada" seleccione income y age como "Variables explicativas" y pulse "Aceptar"
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
# Observese que el modelo se ha establecido a RegModel.1
# Si se quiere predecir los valores para los ingresos (income) para los valores de edad (age) en el conjunto de datos Chile
# Del menu de Rcmdr seleccione:
# "Modelos" -> "Predicir usando el modelo activo" -> "Anadir predicciones a un conjunto de datos existente..."
# En el dialogo seleccione un conjunto de datos compatible con el modelo
# En este caso seleccione Chile
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
Chile$fitted <- predict(RegModel.1, Chile)
# Los valores predichos para ingreso (income) se han guardado como fitted en el conjunto de datos (Chile)

# Example of randomness test for a two level factor
# Load data "AMSsurvey" selecting from Rcmdr menu:
# "Data" -> "Data in packages" -> "Read data set from an attached package..."
# then double-click on "car", click on "AMSsurvey" and on "OK".
# Rcmdr reply with the following command in source pane (R Script)
data(AMSsurvey, package="car")
# To make randomness test on variable "yield", select from Rcmdr menu:
# "Statistics" -> "Nonparametric tests" -> "Randomness test for two level factor..."
# select "sex" and "OK"
# Rcmdr reply with the following command in source pane (R Script)
with(AMSsurvey, twolevelfactor.runs.test(sex))
#	Runs Test
# data:  sex
# Standard Normal = 4.5917, p-value = 0.000004397
# alternative hypothesis: two.sided

# Ejemplo de la opcion de menu "Introducir datos y predecir"
# Cargar los datos "Chile" eligiendo del menu de Rcmdr:
# "Datos" -> "Conjuntos de datos en paquetes" -> "Leer conjunto de datos desde paquete adjunto..."
# pulsar dos veces sobre "car", pulsar sobre "Chile" y sobre "Aceptar".
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
data(Chile, package="car")
# Para construir un modelo seleccione del menu de Rcmdr:
# "Estadisticos" -> "Ajuste de modelos" -> "Regresion lineal..."
# Como "Variable explicada" seleccione income y age como "Variables explicativas" y pulse "Aceptar"
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
# Observese que el modelo se ha establecido a RegModel.1
# Si quiere predecir el ingreso (income) para personas de 35 y 40 anos de edad (age)
# Del menu de Rcmdr seleccione:
# "Modelos" -> "Predecir usando el modelo activo" -> "Introducir datos y predecir"
# En la columna edad (age) introduzca 35 y 40 y cierre el editor.
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
.data <- edit(data.frame(age = numeric(0)))
.data
predict(RegModel.1, .data)
remove(.data)
# Se muestra el valor predicho de ingresos para esas edades usando el modelo activo (RegModel.1)

# Ejemplo de test de aleatoriedad para variable numerica
# Cargar los datos "sweetpotato" eligiendo del menu de Rcmdr:
# "Datos" -> "Conjuntos de datos en paquetes" -> "Leer conjunto de datos desde paquete adjunto..."
# pulsar dos veces sobre "randtests", pulsar sobre "sweetpotato" y "Aceptar".
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
data(sweetpotato, package="randtests")
sweetpotato <- as.data.frame(sweetpotato)
# Para hacer el test de aleatoriead para la variable "yield", elegir del menu de Rcmdr:
# "Estadisticos" -> "Test no parametricos" -> "Test de aleatoriedad para variable numerica..."
# Elegir "yield" y "Aceptar"
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
with(sweetpotato, numeric.runs.test(yield))
#	Runs Test
# data:  yield
# statistic = -4.5751, runs = 17, n1 = 35, n2 = 35, n = 70, p-value = 0.000004759
# alternative hypothesis: nonrandomness

# Ejemplo de test e intervalo de confianza para sigma para una poblacion normal
# Cargar los datos "sweetpotato" eligiendo del menu de Rcmdr:
# "Datos" -> "Conjuntos de datos en paquetes" -> "Leer conjunto de datos desde paquete adjunto..."
# pulsar dos veces sobre "randtests", pulsar sobre "sweetpotato" y "Aceptar".
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
data(sweetpotato, package="randtests")
sweetpotato <- as.data.frame(sweetpotato)
# Para hacer el test de aleatoriead para la variable "yield", elegir del menu de Rcmdr:
# "Estadisticos" -> "Test no parametricos" -> "Test Chi-cuadrado para una muestra..."
# Elegir "yield" y "Aceptar"
# Rcmdr responde con la siguiente instruccion en el cuadro de instrucciones (R Script)
with(sweetpotato, sigma.test(yield[!is.na(yield)], alternative='two.sided', sigmasq=1.0, conf.level=0.95))
#	One sample Chi-squared test for variance
# data:  yield[!is.na(yield)]
# X-squared = 6514.8, df = 69, p-value < 2.2e-16
# alternative hypothesis: true variance is not equal to 1
# 95 percent confidence interval:
#   69.41231 135.93966
# sample estimates:
# var of yield[!is.na(yield)] 
#                    94.41731 

### Quality control extensions

types.withsamplesize <- c('c', 'np', 'p', 'u')
types.multicolumn <- c('R', 'S', 'xbar')

gettext("Phase I...", domain="R-RcmdrPlugin.UCA")
gettext("Phase I (multiple columns)...", domain="R-RcmdrPlugin.UCA")
gettext("Phase II (multiple columns)...", domain="R-RcmdrPlugin.UCA")
gettext("Phase II from data (multiple columns)...", domain="R-RcmdrPlugin.UCA")
gettext("Phase II from parameters (multiple columns)...", domain="R-RcmdrPlugin.UCA")

### Auxiliary function to all quality control for attributes
.qccMenu <- function(dialogtitle, graphtitle, x1title = "", n1title = "", x2title = "", n2title = "", type, phase = c('1', '2', 'p'), help, recall, reset, apply) {
    phase = match.arg(phase)
    initializeDialog(title = dialogtitle)
    ## Parameters
    if (phase == 'p') {
        centerVar <- tclVar("")
        dataFrame <- tkframe(top)
        centerEntry <- tkentry(dataFrame, width="8", textvariable=centerVar)
        if (type %in% types.multicolumn) {
            stddevVar <- tclVar("")
            stddevEntry <- tkentry(top, width="8", textvariable=stddevVar)
        }
    }
    ## Phase I
    x1Box <- variableListBox(top, Numeric(), selectmode=ifelse(type %in% types.multicolumn, "single", "multiple"), initialSelection=NULL, title = x1title)
    n1Box <- variableListBox(top, Numeric(), selectmode="single", initialSelection=NULL, title = n1title)
    subsetBox(subset.expression = gettextRcmdr("<all valid cases>"))
    ## Phase II
    if (phase == '2' || phase == 'p') {
        x2Box <- variableListBox(top, Numeric(), selectmode=ifelse(type %in% types.multicolumn, "single", "multiple"), initialSelection=NULL, title = x2title)
        n2Box <- variableListBox(top, Numeric(), selectmode="single", initialSelection=NULL, title = n2title)
        subset2Box(subset.expression = gettextRcmdr("<all valid cases>"))
        ## Options buttons
        plotall <- tclVar()
        renumber <- tclVar()
        optionsFrame <- tkframe(top)
        plotallcheckBox <- ttkcheckbutton(optionsFrame, variable = plotall)
        renumbercheckBox <- ttkcheckbutton(optionsFrame, variable = renumber)
    }
    onOK <- function() {
        ## Setup and get options values
        if (phase == '2' || phase == 'p') {
            plotall <- (tclvalue(plotall) == "1")
            renumber <- (tclvalue(renumber) == "1")
        } else {
            plotall <- FALSE
            renumber <- FALSE
        }
        ##
        ## Read data
        ##
        ## Read parameters
        if (phase == 'p') {
            center <- as.numeric(tclvalue(centerVar))
            if (is.na(center)) {
                errorCondition(recall = recall, message=gettext("No valid numeric value has been provided for the center parameter", domain="R-RcmdrPlugin.UCA"))
                return()
            }
            if (type %in% types.multicolumn) {
                stddev <- as.numeric(tclvalue(stddevVar))
            }
        }
        ## Read phase I data
        x1 <- getSelection(x1Box)
        if (length(x1) == 0) {
            errorCondition(recall = recall, message=gettext("No data variable was selected (Phase I)", domain="R-RcmdrPlugin.UCA"))
            return()
        }
        if (length(x1) == 1 && type %in% types.multicolumn) {
            errorCondition(recall=recall, message=gettext("Select at least two variables (Phase I)", domain="R-RcmdrPlugin.UCA"))
            return()
        }
        if (type %in% types.withsamplesize) {
            n1 <- getSelection(n1Box)
            if (length(n1) == 0) {
                errorCondition(recall = recall, message=gettext("No sample size variable was selected (Phase I)", domain="R-RcmdrPlugin.UCA"))
                return()
            }
        }
        subset <- trim.blanks(tclvalue(subsetVariable))
        ## Read phase II data
        if (phase == '2' || phase == 'p') {
            x2 <- getSelection(x2Box)
            if (length(x2) == 0) {
                errorCondition(recall = recall, message=gettext("No data variable was selected (Phase II)", domain="R-RcmdrPlugin.UCA"))
                return()
            }
            if (length(x2) == 1 && type %in% types.multicolumn) {
                errorCondition(recall=recall, message=gettext("Select at least two variables (Phase II)", domain="R-RcmdrPlugin.UCA"))
                return()
            }
            if (type %in% types.withsamplesize) {
                n2 <- getSelection(n2Box)
                if (length(n2) == 0) {
                    errorCondition(recall = recall, message=gettext("No sample size variable was selected (Phase II)", domain="R-RcmdrPlugin.UCA"))
                    return()
                }
            }
            subset2 <- trim.blanks(tclvalue(subset2Variable))
        }
        closeDialog()
        ##
        ## Build title
        ##
        if (phase == '1' || plotall) {
            graphtitle <- paste0(graphtitle, ' ', ifelse(type %in% types.multicolumn, paste0('(', paste(x1, collapse = ','), ')'), x1))
            if ((subset != gettextRcmdr("<all valid cases>")) && (subset != "")) graphtitle <- paste0(graphtitle, '[', subset, ifelse(type %in% types.multicolumn, ', ', ''), ']')
        }
        if (phase == '2' || phase == 'p') {
            if (plotall) graphtitle <- paste0(graphtitle, ' ', gettext('and', domain = "R-RcmdrPlugin.UCA"))
            graphtitle <- paste0(graphtitle, ' ', ifelse(type %in% types.multicolumn, paste0('(', paste(x2, collapse = ','), ')'), x2))
            if ((subset2 != gettextRcmdr("<all valid cases>")) && (subset2 != "")) graphtitle <- paste0(graphtitle, '[', subset2, ifelse(type %in% types.multicolumn, ', ', ''), ']')
        }
        if (phase == 'p') {
            graphtitle <- paste0(graphtitle, '\\n', gettext('with Center', domain = "R-RcmdrPlugin.UCA"), ' ', center)
        }
        if (phase == 'p' && type %in% types.multicolumn && !is.na(stddev)) {
            graphtitle <- paste0(graphtitle, ' ', gettext('and StdDev', domain = "R-RcmdrPlugin.UCA"), ' ', stddev)
        }
        ##
        ## Build command
        ##
        command <- paste0("with(", ActiveDataSet(), ", qcc(data = ")
        command <- paste0(command, ifelse(type %in% types.multicolumn, paste0('cbind(', paste(x1, collapse = ','), ')'), x1))
        if ((subset != gettextRcmdr("<all valid cases>")) && (subset != "")) command <- paste0(command, '[', subset, ifelse(type %in% types.multicolumn, ', ', ''), ']') 
        if (type %in% types.withsamplesize) {
            command <- paste0(command, ", sizes = ", n1)
            if ((subset != gettextRcmdr("<all valid cases>")) && (subset != "")) {
                command <- paste0(command, '[', subset, ']')
            }
        }
        if (phase == '2' || phase == 'p') {
            command <- paste0(command, ", newdata = ")
            command <- paste0(command, ifelse(type %in% types.multicolumn, paste0('cbind(', paste(x2, collapse = ','), ')'), x2))
            if ((subset2 != gettextRcmdr("<all valid cases>")) && (subset2 != "")) command <- paste0(command, '[', subset2, ifelse(type %in% types.multicolumn, ', ', ''), ']')
            if (type %in% types.withsamplesize) {
                command <- paste0(command, ", newsizes = ", n2)
                if ((subset2 != gettextRcmdr("<all valid cases>")) && (subset2 != "")) {
                    command <- paste0(command, '[', subset2, ']')
                }
            }
        }
        command <- paste0(command, ", type = \"", type, "\"")
        if (phase == 'p') command <- paste0(command, ", center = ", center)
        if (phase == 'p' && type %in% types.multicolumn && !is.na(stddev)) {
            command <- paste0(command, ", std.dev =", stddev)
        }
        command <- paste0(command, ", title = \"", graphtitle, "\"")
        if (phase == '2' || phase == 'p') {
            if (!plotall) command <- paste0(command, ", chart.all = ", plotall)
            ## Compute length of x2
            if (renumber) {
                lx2 <- paste0("with(", ActiveDataSet())
                if (type %in% types.multicolumn) {
                    lx2 <- paste0(lx2, ", nrow(")
                } else {
                    lx2 <- paste0(lx2, ", length(")
                }
                lx2 <- paste0(lx2, ifelse(type %in% types.multicolumn, paste0('cbind(', paste(x2, collapse = ','), ')'), x2))
                if ((subset2 != gettextRcmdr("<all valid cases>")) && (subset2 != "")) lx2 <- paste0(lx2, '[', subset2, ifelse(type %in% types.multicolumn, ', ', ''), ']')
                lx2 <- paste0(lx2, "))")
                lx2 <- eval(parse(text = lx2))
                command <- paste0(command, ", newlabel = 1:", lx2)
            }
        }
        command <- paste0(command, "))")
        doItAndPrint(command)
        tkdestroy(top)
        tkfocus(CommanderWindow())
    }
    OKCancelHelp(helpSubject = help, reset = reset, apply = apply)
    deltarow <- 0
    ## Parameters
    if (phase == 'p') {
        tkgrid(tklabel(dataFrame, text = paste0(gettext("Center", domain="R-RcmdrPlugin.UCA"), " ")), centerEntry, sticky = "w")
        ## tkgrid(centerEntry, sticky = "w")
        deltarow <- 1
        if (type %in% types.multicolumn) {
            tkgrid(tklabel(dataFrame, text = gettext("Standard Deviation", domain="R-RcmdrPlugin.UCA")), stddevEntry, sticky = "w")
            deltarow <- deltarow + 1
        }
        tkgrid(dataFrame, sticky = "w")
    }
    
    ## Phase I
    tkgrid(getFrame(x1Box), sticky = "w")
    if (type %in% types.withsamplesize) {
        tkgrid(getFrame(n1Box), sticky = "w", row = 0 + deltarow, column = 1)
    }
    tkgrid(subsetFrame, sticky = "w")
    ## Phase II
    if (phase == '2' || phase == 'p') {
        tkgrid(getFrame(x2Box), sticky = "w")
        if (type %in% types.withsamplesize) {
            tkgrid(getFrame(n2Box), sticky = "w", row = 2 + deltarow, column = 1)
        }
        tkgrid(subset2Frame, sticky = "w")
        ## type <- tclvalue(typeVariable)
        tkgrid(plotallcheckBox, tklabel(optionsFrame, text = gettext("Plot all data", domain="R-RcmdrPlugin.UCA")), sticky = "w")
        tkgrid(renumbercheckBox, tklabel(optionsFrame, text = gettext("Renumber 2nd phase data", domain="R-RcmdrPlugin.UCA")), sticky = "w")
        tkgrid(optionsFrame, sticky = "w")
    }
    tkgrid(buttonsFrame, sticky="w", columnspan = 2)
    dialogSuffix()
}

### Function to produce a phase-I c-chart using cchart.p function in qcc package
cchart1Menu <- function()
{
    ## To ensure that menu name is included in pot file
    gettext("Counts", domain="R-RcmdrPlugin.UCA")
    gettext("c-chart (rate)...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("c-chart (rate)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("c-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconformities", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sizes", domain="R-RcmdrPlugin.UCA"),
        type = "c", phase = '1', help = "c-chart", recall = cchart1Menu, reset = "cchart1Menu", apply = "cchart1Menu")
}

### Function to produce a phase-II c-chart using cchart.p function in qcc package
cchart2Menu <- function()
{
    ## To ensure that menu name is included in pot file
    gettext("Counts", domain="R-RcmdrPlugin.UCA")
    gettext("c-chart (rate)...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("c-chart (rate) from data", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("c-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconformities (Phase I)", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sizes (Phase I)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Nonconformities (Phase II)", domain="R-RcmdrPlugin.UCA"),
        n2title = gettext("Sizes (Phase II)", domain="R-RcmdrPlugin.UCA"),
        type = "c", phase = "2", help = "c-chart", recall = cchart2Menu, reset = "cchart2Menu", apply = "cchart2Menu")
}

### Function to produce a phase-II c-chart using cchart.p function in qcc package
cchartpMenu <- function()
{
    ## To ensure that menu name is included in pot file
    gettext("Counts", domain="R-RcmdrPlugin.UCA")
    gettext("c-chart (rate)...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("c-chart (rate) from parameter", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("c-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconformities (Phase I)", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sizes (Phase I)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Nonconformities (Phase II)", domain="R-RcmdrPlugin.UCA"),
        n2title = gettext("Sizes (Phase II)", domain="R-RcmdrPlugin.UCA"),
        type = "c", phase = "p", help = "c-chart", recall = cchartpMenu, reset = "cchartpMenu", apply = "cchartpMenu")
}

### Function to produce a phase-I np-chart using cchart.p function in qcc package
npchart1Menu <- function()
{
    ## To ensure that menu name is included in pot file
    gettext("Attributes", domain="R-RcmdrPlugin.UCA")
    gettext("np-chart (count)", domain="R-RcmdrPlugin.UCA")
    gettext("np-chart (Phase I)...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("np-chart", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("np-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconforming units", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sample size", domain="R-RcmdrPlugin.UCA"),
        type = "np", phase = "1", help = "np-chart", recall = npchart1Menu, reset = "npchart1Menu", apply = "npchart1Menu")
}

### Function to produce a phase-II p-chart using cchart.p function in qcc package
npchart2Menu <- function()
{
    .qccMenu(
        dialogtitle = gettext("np-chart phase II from data", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("np-chart phase II\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconforming units (Phase I)", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sample size (Phase I)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Nonconforming units (Phase II)", domain="R-RcmdrPlugin.UCA"),
        n2title = gettext("Sample size (Phase II)", domain="R-RcmdrPlugin.UCA"),
        type = "np", phase = "2", help = "np-chart",  recall = npchart2Menu, reset = "npchart2Menu", apply = "npchart2Menu")
}


### Function to produce a phase-I np-chart using cchart.p function in qcc package
npchartpMenu <- function()
{
    .qccMenu(
        dialogtitle = gettext("np-chart phase II from parameter", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("np-chart phase II\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconforming units (Phase I)", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sample size (Phase I)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Nonconforming units (Phase II)", domain="R-RcmdrPlugin.UCA"),
        n2title = gettext("Sample size (Phase II)", domain="R-RcmdrPlugin.UCA"),
        type = "np", phase = "p", help = "np-chart", recall = npchartpMenu, reset = "npchartpMenu", apply = "npchartpMenu")
}

### Function to produce a Pareto char using paretochar function in qicharts2 package
paretochartMenu <- function() {
    ## To ensure that menu name is included in pot file
    gettext("Quality Control", domain="R-RcmdrPlugin.UCA")
    initializeDialog(title=gettext("Pareto chart", domain="R-RcmdrPlugin.UCA"))
    variablesBox <- variableListBox(top, Factors(), selectmode="single", initialSelection=NULL, title=gettextRcmdr("Variable"))
    onOK <- function() {
        x <- getSelection(variablesBox)
        if (length(x) == 0) {
            errorCondition(recall=paretochartMenu, message=gettextRcmdr("No variable was selected."))
            return()
        }
        closeDialog()
        ## Apply test
        doItAndPrint(paste("with(", ActiveDataSet(), ", paretochart(", x, "))", sep = ""))
        tkdestroy(top)
        tkfocus(CommanderWindow())
    }
    OKCancelHelp(helpSubject="paretochart", reset = "paretochartMenu", apply = "paretochartMenu")
    tkgrid(getFrame(variablesBox), sticky="nw")
    tkgrid(buttonsFrame, sticky="w")
    dialogSuffix(rows=6, columns=1)
}

### Function to produce a phase-I p-chart using cchart.p function in qcc package
pchart1Menu <- function()
{
    ## To ensure that menu name is included in pot file
    gettext("Attributes", domain="R-RcmdrPlugin.UCA")
    gettext("p-chart (proportion)", domain="R-RcmdrPlugin.UCA")
    gettext("Phase I...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("p-chart", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("p-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconforming units", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sample size", domain="R-RcmdrPlugin.UCA"),
        type = "p", phase = "1", help = "p-chart", recall = pchart1Menu, reset = "pchart1Menu", apply = "pchart1Menu")
}

### Function to produce a phase-II p-chart using cchart.p function in qcc package
pchart2Menu <- function()
{
    gettext("Phase II from data...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("p-chart phase II from data", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("p-chart phase II\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconforming units (Phase I)", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sample size (Phase I)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Nonconforming units (Phase II)", domain="R-RcmdrPlugin.UCA"),
        n2title = gettext("Sample size (Phase II)", domain="R-RcmdrPlugin.UCA"),
        type = "p", phase = "2", help = "p-chart",  recall = pchart2Menu, reset = "pchart2Menu", apply = "pchart2Menu")
}

### Function to produce a phase-I p-chart using cchart.p function in qcc package
pchartpMenu <- function()
{
    gettext("Phase II from parameter...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("p-chart phase II from parameter", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("p-chart phase II\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconforming units (Phase I)", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sample size (Phase I)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Nonconforming units (Phase II)", domain="R-RcmdrPlugin.UCA"),
        n2title = gettext("Sample size (Phase II)", domain="R-RcmdrPlugin.UCA"),
        type = "p", phase = "p", help = "p-chart", recall = pchartpMenu, reset = "pchartpMenu", apply = "pchartpMenu")
}

R1mcMenu <- function()
{
    gettext("Range", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("R-chart phase I (multiple columns)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("R-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        type = "R", phase = "1", help = "R-chart", recall = R1mcMenu, reset = "R1mcMenu", apply = "R1mcMenu")
}

R2mcMenu <- function()
{
    .qccMenu(
        dialogtitle = gettext("R-chart phase II from data (multiple columns)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("R-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements phase I from data (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Measurements phase II from data (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        type = "R", phase = "2", help = "R-chart", recall = R2mcMenu, reset = "R2mcMenu", apply = "R2mcMenu")
}

RpmcMenu <- function()
{
    .qccMenu(
        dialogtitle = gettext("R-chart phase II from parameters (multiple columns)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("R-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements phase I from parameters (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Measurements phase II from parameters (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        type = "R", phase = "p", help = "R-chart", recall = RpmcMenu, reset = "RpmcMenu", apply = "RpmcMenu")
}

S1mcMenu <- function()
{
    .qccMenu(
        dialogtitle = gettext("S-chart (multiple columns)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("S-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        type = "S", phase = "1", help = "S-chart", recall = S1mcMenu, reset = "S1mcMenu", apply = "S1mcMenu")
}

S2mcMenu <- function()
{
    .qccMenu(
        dialogtitle = gettext("S-chart phase II from data (multiple columns)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("S-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements phase I (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Measurements phase II (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        type = "S", phase = "2", help = "S-chart", recall = S2mcMenu, reset = "S2mcMenu", apply = "S2mcMenu")
}

SpmcMenu <- function()
{
    .qccMenu(
        dialogtitle = gettext("S-chart phase II from parameters (multiple columns)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("S-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements phase I (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Measurements phase II (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        type = "S", phase = "p", help = "S-chart", recall = SpmcMenu, reset = "SpmcMenu", apply = "SpmcMenu")
}

### Function to produce a phase-I u-chart using cchart.p function in qcc package
uchart1Menu <- function()
{
    ## To ensure that menu name is included in pot file
    gettext("Counts", domain="R-RcmdrPlugin.UCA")
    gettext("u-chart (average rate)...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("u-chart (average rate)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("u-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconformities", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sizes", domain="R-RcmdrPlugin.UCA"),
        type = "u", phase = "1", help = "u-chart", recall = uchart1Menu, reset = "uchart1Menu", apply = "uchart1Menu")
}

### Function to produce a phase-I u-chart using cchart.p function in qcc package
uchart2Menu <- function()
{
    ## To ensure that menu name is included in pot file
    gettext("Counts", domain="R-RcmdrPlugin.UCA")
    gettext("u-chart (average rate)...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("u-chart phase II from data", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("u-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconformities (Phase I)", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sizes (Phase I)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Nonconformities (Phase II)", domain="R-RcmdrPlugin.UCA"),
        n2title = gettext("Sizes (Phase II)", domain="R-RcmdrPlugin.UCA"),
        type = "u", phase = "2", help = "u-chart", recall = uchart2Menu, reset = "uchart2Menu", apply = "uchart2Menu")
}

### Function to produce a phase-I u-chart using cchart.p function in qcc package
uchartpMenu <- function()
{
    ## To ensure that menu name is included in pot file
    gettext("Counts", domain="R-RcmdrPlugin.UCA")
    gettext("u-chart (average rate)...", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("u-chart phase II from parameter", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("u-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Nonconformities (Phase I)", domain="R-RcmdrPlugin.UCA"),
        n1title = gettext("Sizes (Phase I)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Nonconformities (Phase II)", domain="R-RcmdrPlugin.UCA"),
        n2title = gettext("Sizes (Phase II)", domain="R-RcmdrPlugin.UCA"),
        type = "u", phase = "p", help = "u-chart", recall = uchartpMenu, reset = "uchartpMenu", apply = "uchartpMenu")
}

xbarone1Menu <- function()
{
    gettext("Continuous", domain="R-RcmdrPlugin.UCA")
    gettext("One-at-time data", domain="R-RcmdrPlugin.UCA")
    .qccMenu(
        dialogtitle = gettext("One-at-time data", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements", domain="R-RcmdrPlugin.UCA"),
        type = "xbar.one", help = "xbar.one-chart", recall = xbarone1Menu, reset = "xbarone1Menu", apply = "xbarone1Menu")
}

xbar1mcMenu <- function()
{
    .qccMenu(
        dialogtitle = gettext("xbar-chart (multiple columns)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("xbar-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        type = "xbar", phase = "1", help = "xbar-chart", recall = xbar1mcMenu, reset = "xbar1mcMenu", apply = "xbar1mcMenu")
}

xbar2mcMenu <- function()
{
    .qccMenu(
        dialogtitle = gettext("xbar-chart phase II from data (multiple columns)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("xbar-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements phase I (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Measurements phase II (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        type = "xbar", phase = "2", help = "xbar-chart", recall = xbar2mcMenu, reset = "xbar2mcMenu", apply = "xbar2mcMenu")
}

xbarpmcMenu <- function()
{
    .qccMenu(
        dialogtitle = gettext("xbar-chart phase II from parameters (multiple columns)", domain="R-RcmdrPlugin.UCA"),
        graphtitle = gettext("xbar-chart\\nfor", domain="R-RcmdrPlugin.UCA"),
        x1title = gettext("Measurements phase I (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        x2title = gettext("Measurements phase II (pick two variables or more)", domain="R-RcmdrPlugin.UCA"),
        type = "xbar", phase = "p", help = "xbar-chart", recall = xbarpmcMenu, reset = "xbarpmcMenu", apply = "xbarpmcMenu")
}

if (getRversion() >= '2.15.1') globalVariables(c('alternativeFrame', 'alternativeVariable', 'buttonsFrame', 'subsetFrame', 'subsetVariable', 'subset2Frame', 'subset2Variable', 'top', 'types.multicolum'))

### Some Rcmdr useful extensions

### Note for the next function (last modified: 2013-01-24 by J. Fox): the following function (with contributions from Richard Heiberger and Milan Bouchet-Valat)
### can be included in any Rcmdr plug-in package to cause the package to load
### the Rcmdr if it is not already loaded
.onAttach <- function(libname, pkgname) {
    if (!interactive()) return()
    putRcmdr("slider.env", new.env())    
    Rcmdr <- options()$Rcmdr
    plugins <- Rcmdr$plugins
    if (!pkgname %in% plugins) {
        Rcmdr$plugins <- c(plugins, pkgname)
        options(Rcmdr=Rcmdr)
        if("package:Rcmdr" %in% search()) {
            if(!getRcmdr("autoRestart")) {
                closeCommander(ask=FALSE, ask.save=TRUE)
                Commander()
            }
        }
        else {
            Commander()
        }
    }
}

## Help menu options
browseRUCAWebsite <- function() {
    gettext("R-UCA project website")
    browseURL(gettext("https://knuth.uca.es/R/doku.php?id=inicio"))
    }

browseRcmdrPluginUCA <- function() {
    gettext("RcmdrPlugin.UCA package website")
    browseURL(gettext("https://knuth.uca.es/R/doku.php?id=rcmdrplugin.uca"))
}

checkRUCAversion <- function() {
    gettext("Check R-UCA package version")
    browseURL(paste0(gettext("https://knuth.uca.es/version_R-UCA.php?lang=en&version="), version['major'], '.', version['minor']))
}


## Functions to handle with binary variables
isBinary <- function(x) is.numeric(x) && all((x == 1) | (x == 0) | is.na(x))
Binaries <- function(dataSet = ActiveDataSet()) listBinaries(dataSet = dataSet)
BinariesP <- function(n=1) activeDataSetP() && length(listBinaries()) >= n
listBinaries <- function(dataSet = ActiveDataSet())
{
    variables <- listVariables(dataSet)
    if(length(variables) == 0) return(NULL)
    index <- sapply(variables, FUN = function(.x) isBinary(eval(parse(text=.x), envir=get(ActiveDataSet(), envir=.GlobalEnv))))
    if (!any(index)) return(NULL)
    variables[index]
}
## Dicotomic variables are binaries + two level factors
Dicotomics <- function(dataSet = ActiveDataSet()) listDicotomics(dataSet = dataSet)
DicotomicsP <- function(n=1) activeDataSetP() && length(listDicotomics()) >= n
listDicotomics <- function(dataSet = ActiveDataSet()) sort(c(listTwoLevelFactors(dataSet = dataSet), listBinaries(dataSet = dataSet)))

### Function to input data and predict values using active model
input2predict <- function() {
    ## To ensure that menu name is included in pot file
    gettext("Predict using active model", domain="R-RcmdrPlugin.UCA")
    gettext("Input data and predict...", domain="R-RcmdrPlugin.UCA")
    doItAndPrint(paste0(".data <- edit(", ActiveDataSet(), "[0,])"))
    doItAndPrint(".data")
    doItAndPrint(paste0("predict(", ActiveModel(), ", .data)"))
    doItAndPrint("remove(.data)")
}

### Kolmogorov-Smirnov for two samples
ks2samplesTest <- function() {
    ## To ensure that menu name is included in pot file
    gettext("Kolmogorov-Smirnov test for two samples...", domain="R-RcmdrPlugin.UCA")
    ## Build dialog
    initializeDialog(title=gettext("Kolmogorov-Smirnov test for two samples", domain="R-RcmdrPlugin.UCA"))
    variablesBox1 <- variableListBox(top, Numeric(), selectmode="single", initialSelection=NULL, title=gettextRcmdr("Variable (pick one)"))
    variablesBox2 <- variableListBox(top, Numeric(), selectmode="single", initialSelection=NULL, title=gettextRcmdr("Variable (pick another one)"))
    onOK <- function(){
        x <- getSelection(variablesBox1)
        if (length(x) == 0) {
            errorCondition(recall=ks2samplesTest, message=gettext("No variable were selected for fist one.", domain="R-RcmdrPlugin.UCA"))
            return()
        }
        y <- getSelection(variablesBox2)
        if (length(y) == 0) {
            errorCondition(recall=ks2samplesTest, message=gettext("No variable were selected for second one.", domain="R-RcmdrPlugin.UCA"))
            return()
        }
        if (x == y) {
            errorCondition(recall=ks2samplesTest, message=gettext("First variable and second one are the same.", domain="R-RcmdrPlugin.UCA"))
            return()
        }
        closeDialog()
        ## Apply test
        doItAndPrint(paste("with(", ActiveDataSet(), ", ks.test(", x, ", ", y, "))", sep = ""))
        tkfocus(CommanderWindow())
    }
    OKCancelHelp(helpSubject="Kolmogorov-Smirnov test", reset = "ks2samplesTest", apply = "ks2samplesTest")
    tkgrid(getFrame(variablesBox1), sticky="w", row = 1)
    tkgrid(getFrame(variablesBox2), sticky="w", row = 1, column = 1)
    tkgrid(buttonsFrame, sticky="w", columnspan = 2)
    dialogSuffix()
}

### Function to predict values for existing data set
predict4dataset <- function() {
    ## To ensure that menu name is included in pot file
    gettext("Predict values for existing dataset...", domain="R-RcmdrPlugin.UCA")
    dataSets <- listDataSets()
    .activeDataSet <- ActiveDataSet()
    initializeDialog(title=gettextRcmdr("Select Data Set"))
    dataSetsBox <- variableListBox(top, dataSets, title=gettextRcmdr("Data Sets (pick one)"), initialSelection=if (is.null(.activeDataSet)) NULL else which(.activeDataSet == dataSets) - 1)
    onOK <- function(){
        selection <- getSelection(dataSetsBox)
        closeDialog()
        setBusyCursor()
        on.exit(setIdleCursor())
        doItAndPrint(paste0(selection, "$fitted.", ActiveModel(), " <- predict(", ActiveModel(), ", ", selection, ")"))
        if (selection != .activeDataSet) activeDataSet(selection)
        tkfocus(CommanderWindow())
    }
    OKCancelHelp()
    tkgrid(getFrame(dataSetsBox), sticky="nw")
    tkgrid(buttonsFrame, sticky="w")
    dialogSuffix()
}

### Function to be called by Rcmdr to test for randomness using runs.test from tseries packages
randomnessFTest <- function() {
    ## To ensure that menu name is included in pot file
    gettext("Randomness test for two level factor...", domain="R-RcmdrPlugin.UCA")
    ## Build dialog
    initializeDialog(title=gettext("Randomness test for two level factor", domain="R-RcmdrPlugin.UCA"))
    variablesBox <- variableListBox(top, TwoLevelFactors(), selectmode="single", initialSelection=NULL, title=gettextRcmdr("Variable (pick one)"))
    onOK <- function(){
        x <- getSelection(variablesBox)
        if (length(x) == 0) {
            errorCondition(recall=randomnessNTest, message=gettextRcmdr("No variable were selected."))
            return()
        }
        closeDialog()
        ## Apply test
        doItAndPrint(paste("with(", ActiveDataSet(), ", twolevelfactor.runs.test(", x, "))", sep = ""))
        tkfocus(CommanderWindow())
    }
    OKCancelHelp(helpSubject="Randomness test", reset = "randomnessFTest", apply = "randomnessFTest")
    tkgrid(getFrame(variablesBox), sticky="nw")
    tkgrid(buttonsFrame, sticky="w")
    dialogSuffix(rows=6, columns=1)
}

### Function to be called by Rcmdr to test for randomness using runs.test from randtest packages
randomnessNTest <- function() {
    ## To ensure that menu name is included in pot file
    gettext("Randomness test for numeric variable...", domain="R-RcmdrPlugin.UCA")
    ## Build dialog
    initializeDialog(title=gettext("Randomness test for numeric variable", domain="R-RcmdrPlugin.UCA"))
    variablesBox <- variableListBox(top, Numeric(), selectmode="single", initialSelection=NULL, title=gettextRcmdr("Variable (pick one)"))
    onOK <- function(){
        x <- getSelection(variablesBox)
        if (length(x) == 0) {
            errorCondition(recall=randomnessNTest, message=gettextRcmdr("No variables were selected."))
            return()
        }
        closeDialog()
        ## Apply test
        doItAndPrint(paste("with(", ActiveDataSet(), ", numeric.runs.test(", x, "))", sep = ""))
        tkfocus(CommanderWindow())
    }
    OKCancelHelp(helpSubject="Randomness test", reset = "randomnessNTest", apply = "randomnessNTest")
    tkgrid(getFrame(variablesBox), sticky="nw")
    tkgrid(buttonsFrame, sticky="w")
    dialogSuffix(rows=6, columns=1)
}

SampleSizeZMenu <- function() {
    ## Initialize dialog
    dialogName <- "SampleSizeZMenu"
    dialogTitle <- gettext("Normal mean with known variance", domain="R-RcmdrPlugin.UCA")
    defaults <- list(difference = "")
    dialog.values <- getDialog(dialogName, defaults=defaults)
    initializeDialog(title=dialogTitle)
    ## Define functions to handle buttons
    onOK <- function(){
        ##difference <- tclvalue(differenceVariable)
        closeDialog()
        tkfocus(CommanderWindow())
        ##difference <- tclvalue(difference)
        ##inputDialog(dialogName, list(difference = difference))
        doItAndPrint("-10:0")
        doItAndPrint("1:10")
    }
    OKCancelHelp(helpSubject="pwr.norm.test", reset=dialogName, apply=dialogName)
    ## Define tk objects
    entryFrame <- tkframe(top)
    differenceFrame <- tkframe(entryFrame)
    differenceVariable <- tclVar(dialog.values$difference)
    differenceField <- ttkentry(differenceFrame, width="6", textvariable = differenceVariable)
    ##tkgrid(entryFrame, sticky="w")
    ##tkgrid(labelRcmdr(differenceFrame, text = gettext("Difference to detect =", domain="R-RcmdrPlugin.UCA")), differenceField, sticky="w")
    tkgrid(buttonsFrame, sticky="w")
    ##dialogSuffix(columns=3)
    dialogSuffix()
}

sigmaTest <- function() {
    ## This function is developed from singleSampleTTest in Rcmdr and use function sigma.test in package TeachingDemos
    ## To ensure that menu name is included in pot file
    gettext("Single-Sample Variance Test...", domain="R-RcmdrPlugin.UCA")
    defaults <- list (initial.x = NULL, initial.alternative = "two.sided", initial.level = "0.95", initial.sigma = "1.0")
    dialog.values <- getDialog ("sigmaTest", defaults)
    initializeDialog(title = gettext("Single-Sample Variance Test", domain="R-RcmdrPlugin.UCA"))
    xBox <- variableListBox(top, Numeric(), title = gettextRcmdr("Variable (pick one)"), initialSelection = varPosn(dialog.values$initial.x, "numeric"))
    onOK <- function() {
        x <- getSelection(xBox)
        if (length(x) == 0) {
            errorCondition(recall = sigmaTest, message = gettextRcmdr("You must select a variable."))
            return()
        }
        alternative <- tclvalue(alternativeVariable)
        level <- tclvalue(confidenceLevel)
        sigma <- tclvalue(sigmaVariable)
        putDialog("sigmaTest", list (initial.x = x, initial.alternative = alternative, initial.level = level, initial.sigma = sigma))
        closeDialog()
        doItAndPrint(paste("with(", ActiveDataSet (), ", sigma.test(", x, "[!is.na(", x, ")], alternative='", alternative, "', sigmasq=", sigma, ", conf.level=", level, "))", sep = ""))
        tkdestroy(top)
        tkfocus(CommanderWindow())
    }
    OKCancelHelp(helpSubject = "sigma.test", reset = "sigmaTest", apply = "sigmaTest")
    optionsFrame <- tkframe(top)
    radioButtons(optionsFrame, name = "alternative", buttons = c("twosided", "less", "greater"), values = c("two.sided", "less", "greater"), labels = paste(gettext("Population variance", domain="R-RcmdrPlugin.UCA"), c("!= sigma0^2", "< sigma0^2", "> sigma0^2")), title = gettextRcmdr("Alternative Hypothesis"), initialValue = dialog.values$initial.alternative)
    rightFrame <- tkframe(optionsFrame)
    confidenceFrame <- tkframe(rightFrame)
    confidenceLevel <- tclVar(dialog.values$initial.level)
    confidenceField <- ttkentry(confidenceFrame, width = "6", textvariable = confidenceLevel)
    sigmaFrame <- tkframe(rightFrame)
    sigmaVariable <- tclVar(dialog.values$initial.sigma)
    sigmaField <- ttkentry(sigmaFrame, width = "8", textvariable = sigmaVariable)
    tkgrid(getFrame(xBox), sticky = "nw")
    tkgrid(labelRcmdr(rightFrame, text = ""), sticky = "w")
    tkgrid(labelRcmdr(sigmaFrame, text = gettext("Null hypothesis: sigma^2 =", domain="R-RcmdrPlugin.UCA")),  sigmaField, sticky = "w", padx=c(10, 0))
    tkgrid(sigmaFrame, sticky = "w")
    tkgrid(labelRcmdr(confidenceFrame, text = gettextRcmdr("Confidence Level: ")), confidenceField, sticky = "w", padx=c(10, 0))
    tkgrid(confidenceFrame, sticky = "w")
    tkgrid(alternativeFrame, rightFrame, sticky = "nw")
    tkgrid(optionsFrame, sticky="w")
    tkgrid(buttonsFrame, columnspan = 2, sticky = "w")
    tkgrid.configure(confidenceField, sticky = "e")
    dialogSuffix()
}

numeric.runs.test <- function(...) randtest.runs.test(...)
twolevelfactor.runs.test <- function(...) tseries.runs.test(...)

subset2Box <- function (window = top, subset.expression = NULL, model = FALSE) 
{
    tmp <- substitute({
        on.exit(remove(list = objects(pattern = "^\\.\\.", all.names = TRUE)))
        subset2Variable <- if (!is.null(subset.expression)) tclVar(gettextRcmdr(subset.expression)) else if (model) {
                                                                                                        if (currentModel && currentFields$subset != "") tclVar(currentFields$subset) else tclVar(gettextRcmdr("<all valid cases>"))
                                                                                                    } else tclVar(gettextRcmdr("<all valid cases>"))
        subset2Frame <- tkframe(window)
        subset2Entry <- ttkentry(subset2Frame, width = "20", textvariable = subset2Variable)
        subset2Scroll <- ttkscrollbar(subset2Frame, orient = "horizontal", command = function(...) tkxview(subset2Entry, ...))
        tkconfigure(subset2Entry, xscrollcommand = function(...) tkset(subset2Scroll, ...))
        tkgrid(labelRcmdr(subset2Frame, text = gettextRcmdr("Subset expression"), fg = getRcmdr("title.color"), font = "RcmdrTitleFont"), sticky = "w")
        tkgrid(subset2Entry, sticky = "ew")
        tkgrid(subset2Scroll, sticky = "ew")
        tkgrid.columnconfigure(subset2Frame, 0, weight = 1)
    })
    eval(tmp, parent.frame())
}

---
title: "Additional options in Rcmdr using RcmdrPlugin.UCA"
author: "Manuel Munoz-Marquez"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{RcmdrPlugin.UCA}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 6,
  fig.height = 4
)
library(RcmdrPlugin.UCA)
sigma.test <- TeachingDemos::sigma.test
```
# Introduction

The package __RcmdrPlugin.UCA__ adds some options to the Rcmdr menu that are useful for new users in R. Namely:

* Test and confidence interval for variance
* Randomness test for numerical and dichotomous variables
* Prediction of values using the active model

In the following sections, each of these options will be described in detail.

# Test and confidence interval for the variance of a normal population

Within the menu "Statistics" -> "Variances", a new entry is provided to calculate confidence intervals and make contrasts on the variance in a normal population.This option uses the `sigma.test` function of the TeachingDemos package.

## Example of using the "Single-Sample Variance Test..." menu

First we will load the randtest package from which we will load the data. For it:

1. From the Rcmdr menu, choose the option "Tools" -> "Load package(s) ..."
2. Search in the randtest dialog box and select it
3. Press accept

In the message window should appear `[x] NOTE: Packages loaded: randtest`.
If randtest does not appear in the list, you must first install the package.

Next we will load a set of data, for example, "sweetpotato" through the following steps:

1. Choose from the Rcmdr menu: "Data" -> "Package data sets" -> "Read data set from attached package..."
2. Press twice on "randtests"
3. Click on "sweetpotato" and on "Accept".

Rcmdr reply with the following text in the instruction tab (R Script)

```{r, include = TRUE}
data(sweetpotato, package = "randtests")
sweetpotato <- as.data.frame (sweetpotato)
```

In the message window it will appear `[x] NOTE: The data set sweetpotato has 70 rows and 4 columns.` and in the dialog box attached to the label "Data set:" "sweetpotato" will appear.

To build the confidence interval for sigma for the variable "yield", select from the Rcmdr menu: "Statistics" -> "Variances" -> "Single-Sample Variance Test..." select "yield" and "OK". Rcmdr responds with the following instruction in the instruction tab (R Script)
```{r, include = TRUE, results = 'hide'}
with(sweetpotato, sigma.test(yield[!is.na(yield)], alternative='two.sided', sigmasq=1.0, conf.level=0.95))
```
and in the output tab
```{r, include = TRUE}
with(sweetpotato, sigma.test(yield[!is.na(yield)], alternative='two.sided', sigmasq=1.0, conf.level=0.95))
```

The null hypothesis $\sigma = 1$ has been rejected at a confidence level of 95%, obtaining a confidence interval at that level for $\sigma$ of $(69.41231, 135.93966)$.

If desired, in the previous dialog you can specify:

1. the alternative hypothesis
2. the value of sigma under the null hypothesis
3. the level of trust.

# Randomness test

Two options are provided within the "Non-parametric Test" menu to perform the randomness test according to the type of variable.

## Randomness test for a dichotomous variable

Within the menu "Statistics" -> "Non-parametric tests" -> "Randomness test for a factor of two levels...", a new entry is provided to test the randomness of a factor-type variable with two levels. This option uses the `runs.test` function of the tseries package, although to avoid conflicts it has been renamed as `twolevelfactor.runs.test`.

### Example of using the menu "Randomness test for a two-level factor..."

First we will load a set of data, for example, "AMSsurvey" using the following steps:

1. Choose from the Rcmdr menu: "Data" -> "Data sets in packages" -> "Read data set from attached package..."
2. Press twice on "carData"
3. Click on "AMSsurvey" and on "Accept".

Rcmdr reply with the following instruction in the instruction tab (R Script)

```{r, include = TRUE}
data(AMSsurvey, package = "carData")
```

In the message window it will appear `[x] NOTE: The data set AMSsurvey has 24 rows and 5 columns.` and in the dialog box attached to the label "Data set:" "AMSsurvey" will appear.

To make the randomness test variable "sex", select from the Rcmdr menu: "Statistics" -> "Non-parametric test" -> "Randomness test for a factor with two levels..." select "sex" and "OKAY". Rcmdr responds with the following instruction in the instruction tab (R Script)
```{r, include = TRUE, results = 'hide'}
with (AMSsurvey, twolevelfactor.runs.test (sex))
```
and in the output tab
```{r, include = TRUE}
with (AMSsurvey, twolevelfactor.runs.test (sex))
```

We rejected the null hypothesis of randomness with a p-value of `r with(AMSsurvey, twolevelfactor.runs.test (sex))$p.value`, before proceeding with the study we would have to investigate the cause of this lack of randomness.

## Randomness test for a numerical variable

Within the "Statistics" menu -> "Non-parametric tests" -> "Randomness test for a numeric variable ...", a new entry is provided to test the randomness of a numeric variable. This option uses the `runs.test` function of the randtest package, although to avoid conflicts it has been renamed as `numeric.runs.test`.

### Example of using the menu "Randomness test for a numeric variable ..."

First, if we have not already done so, we will load the sweetpotato data set.
If the data set is loaded but not active, click the button next to the text "Data set:", select sweetpotato and click "OK".
The text of the button changes to "sweetpotato".

To make the randomness test to the variable "yield", we select from the Rcmdr menu: "Statistics" -> "Non-parametric test" -> "Randomness test for a numeric variable ..." select "yield" and "OK".
Rcmdr responds with the following instruction in the instruction box (R Script)
```{r, include = TRUE, results = 'hide'}
with (sweetpotato, numeric.runs.test (yield))
```
and in the output box
```{r, include = TRUE}
with (sweetpotato, numeric.runs.test (yield))
```

The randomness hypothesis is rejected with a p-value of `r with(sweetpotato, numeric.runs.test(yield))$p.value`, before proceeding with the study we would have to investigate the cause of this lack of randomness.

# Make predictions using active model

The menu entry "Predict using active model", in models menu, has two options to predict data using active model depending on how the data for predictor variables will be provided.

## Input data and predict

If you select "Input data and predict", a new data set, as a data.frame, will be created and the editor will be invoked. Then you can entry the values of the predictor variable that you want to use for prediction, the values for non predictor variables are not required. When you close the data editor the predicted values for predicted variable are shown.

### Example of use of "Input data and predict..." menu entry

Load data "Chile" selecting from Rcmdr menu: "Data" -> "Data in packages" -> "Read data set from an attached package..." then double-click on "carData", click on "Chile" and on "OK".

Rcmdr reply with the following command in source pane (R Script)

```{r, include = TRUE}
data(Chile, package="carData")
```

In the message window it will appear `[x] NOTE: The data set Chile has 2700 rows and 8 columns.` and in the dialog box attached to the label "Data set:" "Chile" will appear.

To build a model select from Rcmdr menu: "Statistics" -> "Model fit" -> "Linear Regresion...". As "Response variable" select income and age as "Explanatory variables" and click on "OK". Rcmdr reply with the following command in source pane (R Script)
```{r include = TRUE, results = 'hide'}
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
```
in the output box
```{r include = TRUE}
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
```

Note that the active model is set to RegModel.1. 
So if you want to predict a new value for a 35 and 40 age person. 
Select from Rcmdr menu: "Models" -> "Predict using active model" -> "Input data and predict". 
In age column input 35 and 40 and then close the editor. 
Rcmdr reply with the following command in source pane (R Script)
```{r include=TRUE, echo = FALSE, results='hide'}
edit <- function(x)
{
.data <- Chile[0,]
.data[1:2,] <- NA
.data$age <- c(34, 45)
.data
}
```
```{r include = TRUE, results = 'hide'}
.data <- edit(Chile[0,])
.data
predict(RegModel.1, .data)
remove(.data)
```
and in the output box if 34 and 45 are given as values for age
```{r include = TRUE}
.data <- edit(Chile[0,])
.data
predict(RegModel.1, .data)
remove(.data)
```
And output the predicted value of income for that age using active model (RegModel.1)




## Add predictions to existing dataset

If you select "Models" -> "Predict using active model" -> "Add predictions to existing dataset..." the predictions are added to the selected data set using the active model and the selected data set for the values of the explanatory variables. 
After selecting this option, the user can select an existing data set using dialog box.

If the data set does not provides the values for all predicting variables an error will occur and no predicted values will be provided.

Unlike the menu option "Add observation statistics to data...", this option can be used with a different data set than the one used to construct the model, if that dataset provides the values for all the predictor variables.

## Example of use of "Add predictions to existing dataset..." menu entry

Load data "Chile" as in the previous example.

To build a model select from Rcmdr menu: "Statistics" -> "Model fit" -> "Linear Regresion..." as "Response variable" select income and age as "Explanatory variables" and click on "OK". Rcmdr reply with the following command in source pane (R Script)
```{r include = TRUE, results = 'hide'}
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
```
and in the output box
```{r include = TRUE}
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
```

Note that the active model is set to RegModel.1 So if you want to predict the values for income for age data in Chile dataset. Select from Rcmdr menu: "Models" -> "Predict using active model" -> "Add predictions to existing dataset...". In the dialog select a compatible dataset with the model. In this case select Chile. Rcmdr reply with the following command in source pane (R Script)
```{r include = TRUE, results = 'hide'}
Chile$fitted.RegModel.1 <- predict(RegModel.1, Chile)
```
and in the output box
```{r include = TRUE}
Chile$fitted.RegModel.1 <- predict(RegModel.1, Chile)
```


The predicted value of income has been saved as fitted.RegModel.1 in the selected dataset (Chile). 
You can see the added values using the button for visualizing the data set.

---
title: "Opciones adicionales en Rcmdr usando RcmdrPlugin.UCA"
author: "Manuel Munoz-Marquez"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{RcmdrPlugin.UCA.es}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 6,
  fig.height = 4
)
library(RcmdrPlugin.UCA)
sigma.test <- TeachingDemos::sigma.test
```

# Introducción

El paquete __RcmdrPlugin.UCA__ añade algunas opciones al menú de Rcmdr que son útiles para los usuarios noveles en R. A saber:

* Constraste de hipótesis e intervalo de confianza para la varianza
* Test de aleatoriedad para variables numéricas y dicotómicas
* Predicción de valores usando el modelo activo

En las siguientes secciones se describirán detalladamente cada una de estas opciones.

# Test de hipótesis e intervalo de confianza para la varianza de una población normal

Dentro del menú "Estadísticos" -> "Varianzas", se proporcionan una nueva entrada para calcular intervalos de confianza y hacer contrastes sobre la varianza en una población normal. Esta opción usa la función `sigma.test` del paquete TeachingDemos.

## Ejemplo de uso del menú "Test de varianza para una muestra..."

En primer lugar cargaremos el paquete randtest del cual vamos a cargar los datos. Para ello:

1. Del menú de Rcmdr elegir la opción "Herramientas" -> "Cargar paquete(s)..."
2. Buscar en el cuadro de diálogo randtest y seleccionarlo
3. Pulsar aceptar

En la ventana de mensajes debe aparecer `[x] NOTA: Paquetes cargados: randtest`. 
Si randtest no aparece en la lista deberá previamente instalar el paquete.

A continuación cargaremos un conjunto de datos, por ejemplo, "sweetpotato" mediante los pasos siguientes:

1. Elegir del menú de Rcmdr: "Datos" -> "Conjuntos de datos en paquetes" -> "Leer conjunto de datos desde paquete adjunto..."
2. Pulsar dos veces sobre "randtests"
3. Pulsar sobre "sweetpotato" y sobre "Aceptar".

Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)

```{r, include = TRUE}
data(sweetpotato, package="randtests")
sweetpotato <- as.data.frame(sweetpotato)
```

En la ventana de mensajes aparecerá `[x] NOTA: El conjunto de datos sweetpotato tiene 70 filas y 4 columnas.` y en el cuadro de diálogo anexo a la etiqueta "Conjunto de datos:" aparecerá "sweetpotato".

Para construir el intervalo de confianza para sigma para la variable "yield" (rendimiento), seleccione del menú de Rcmdr: "Estadísticos" -> "Varianzas" -> "Test de varianza para una muestra..." seleccione "yield" y "OK". Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)
```{r, include = TRUE, results = 'hide'}
with(sweetpotato, sigma.test(yield[!is.na(yield)], alternative='two.sided', sigmasq=1.0, conf.level=0.95))
```
y en el cuadro de salida
```{r, include = TRUE}
with(sweetpotato, sigma.test(yield[!is.na(yield)], alternative='two.sided', sigmasq=1.0, conf.level=0.95))
```

Se ha rechazado la hipótesis nula $\sigma = 1$ a un nivel de confianza del 95%, obeniéndose un intervalo de confianza a dicho nivel para $\sigma$ de $(69.41231, 135.93966)$.

Si se desea en el cuadro de diálogo anterior se puede especificar:

1. la hipótesis alternativa
2. el valor de sigma bajo la hipótesis nula
3. el nivel de confianza.

# Test de aleatoriedad

Se proporcionan dos opciones dentro del menú "Test no paramétricos" para realizar el test de aleatoriedad según el tipo de variable.

## Test de aleatoriedad para una variable dicotómica

Dentro del menú "Estadísticos" -> "Test no paramétricos" -> "Test de aleatoriedad para un factor de dos niveles...", se proporcionan una nueva entrada para contrastar la aleatoriedad de una variable de tipo factor con dos niveles. Esta opción usa la función `runs.test` del paquete tseries, si bien para evitar conflictos ha sido renombrada a `twolevelfactor.runs.test`.

### Ejemplo de uso del menú "Test de aleatoriedad para un factor de dos niveles..."

En primer lugar cargaremos un conjunto de datos, por ejemplo, "AMSsurvey" mediante los pasos siguientes:

1. Elegir del menú de Rcmdr: "Datos" -> "Conjuntos de datos en paquetes" -> "Leer conjunto de datos desde paquete adjunto..."
2. Pulsar dos veces sobre "carData"
3. Pulsar sobre "AMSsurvey" y sobre "Aceptar".

Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)

```{r, include = TRUE}
data(AMSsurvey, package="carData")
```

En la ventana de mensajes aparecerá `[x] NOTA: El conjunto de datos AMSsurvey tiene 24 filas y 5 columnas.` y en el cuadro de diálogo anexo a la etiqueta "Conjunto de datos:" aparecerá "AMSsurvey".

Para hacer el test de aleatoriedad a la variable "sex", seleccionamos del menú de Rcmdr: "Estadísticos" -> "Test no paramétricos" -> "Test de aleatoriedad para un factor con dos niveles...", seleccionamos "sex" y "OK". Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script) 
```{r, include = TRUE, results = 'hide'}
with(AMSsurvey, twolevelfactor.runs.test(sex))
```
y en el cuadro de salida
```{r, include = TRUE}
with(AMSsurvey, twolevelfactor.runs.test(sex))
```

Se ha rechazado la hipótesis nula de aleatoriedad con un p-valor de `r with(AMSsurvey, twolevelfactor.runs.test(sex))$p.value`, antes de proseguir con el estudio habría que investigar la causa de esta falta de aleatoriedad.

## Test de aleatoriedad para una variable numérica

Dentro del menú "Estadísticos" -> "Test no paramétricos" -> "Test de aleatoriedad para una variable numérica...", se proporcionan una nueva entrada para contrastar la aleatoriedad de una variable de tipo numérico. Esta opción usa la función `runs.test` del paquete randtest, si bien para evitar conflictos ha sido renombrada a `numeric.runs.test`.

### Ejemplo de uso del menú "Test de aleatoriedad para una variable numérica..."

En primer lugar, si aún no lo hemos hecho, cargaremos el conjunto de datos sweetpotato. 
Si el conjunto de datos está cargado pero no está activo, se pulsa el botón anexo al texto "Conjunto de datos:", se selecciona sweetpotato y se pulsa "Aceptar". 
El texto del botón cambia a "sweetpotato". 

Para hacer el test de aleatoriedad a la variable "yield" (rendimiento), seleccionamos del menú de Rcmdr: "Estadísticos" -> "Test no paramétricos" -> "Test de aleatoriedad para una variable numérica..." seleccionamos "yield" y "OK".
Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script) 
```{r, include = TRUE, results = 'hide'}
with(sweetpotato, numeric.runs.test(yield))
```
y en el cuadro de salida
```{r, include = TRUE}
with(sweetpotato, numeric.runs.test(yield))
```

La hipótesis de aleatoriedad se rechaza con un p-valor de `r with(sweetpotato, numeric.runs.test(yield))$p.value`, antes de proseguir con el estudio habría que investigar la causa de esta falta de aleatoriedad.


# Predicciones usando el modelo activo

La entrada de menú "Predecir usando el modelo activo", en el menú modelos, tiene dos opciones para predecir datos usando el modelo activo dependiendo de cómo se proporcionen los valores para las variables predictoras.

## Introducir datos y predecir

Si selecciona "Modelos" -> "Predecir usando el modelo activo" -> "Introducir datos y predecir", se creará un nuevo conjunto de datos, como un data.frame y se abrirá el editor automáticamente. A continuación, se pueden introducir los valores de la variable predictora que se desea utilizar para la predicción, no es necesario introducir los valores de las variables no predictoras. Al cerrar el editor de datos se muestran los valores predichos.

### Ejemplo de uso del menú "Introducir datos y predecir..."

Cargar los datos "Chile" eligiendo del menu de Rcmdr: "Datos" -> "Conjuntos de datos en paquetes" -> "Leer conjunto de datos desde paquete adjunto..." pulsar dos veces sobre "carData", pulsar sobre "Chile" y sobre "Aceptar". Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)

```{r, include = TRUE}
data(Chile, package="carData")
```

En la ventana de mensajes aparecerá `[x] NOTA: El conjunto de datos car tiene 2700 filas y 8 columnas.` y en el cuadro de diálogo anexo a la etiqueta "Conjunto de datos:" aparecerá "Chile".

Para construir un modelo seleccione del menú de Rcmdr: "Estadisticos" -> "Ajuste de modelos" -> "Regresion lineal...". Como "Variable explicada" seleccione income y age como "Variables explicativas" y pulse "Aceptar". Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)
```{r include = TRUE, results = 'hide'}
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
```
y en el cuadro de salida
```{r include = TRUE}
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
```

Obsérvese que el modelo se ha establecido a RegModel.1. 
Si quiere predecir el ingreso (income) para personas de 35 y 40 años de edad (age). 
Del menú de Rcmdr seleccione: "Modelos" -> "Predecir usando el modelo activo" -> "Introducir datos y predecir". 
En la columna edad (age) introduzca 35 y 40 y cierre el editor. 
Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)
```{r include=TRUE, echo = FALSE, results='hide'}
edit <- function(x)
{
.data <- Chile[0,]
.data[1:2,] <- NA
.data$age <- c(34, 45)
.data
}
```
```{r include = TRUE, results = 'hide'}
.data <- edit(Chile[0,])
.data
predict(RegModel.1, .data)
remove(.data)
```
y en el cuadro de salida, suponiendo que se han introducido 35 y 45 en la columna age
```{r include = TRUE}
.data <- edit(Chile[0,])
.data
predict(RegModel.1, .data)
remove(.data)
```
Se muestra el valor predicho de ingresos para esas edades usando el modelo activo (RegModel.1).


## Opción "Agregar predicciones a un conjunto de datos existente ..."

Si se selecciona "Modelos" -> "Predecir usando el modelo activo" -> Agregar predicciones a un conjunto de datos existente ..." se agregan las predicciones usando el modelo activo al conjunto de datos seleccionado, usando para las variables predictoras los valores de dicho conjunto de datos. 
Después de seleccionar esta opción, el usuario o usuaria puede seleccionar un conjunto de datos existente utilizando el cuadro de diálogo correspondiente.

Si el conjunto de datos no proporciona los valores para todas las variables predictoras, se producirá un error y no se proporcionarán valores predichos.

A diferencia de la opción del menú "Añadir las estadísticas de las observaciones a los datos...", esta opción puede ser usada con un conjunto de datos distinto al que se ha utilizado para construir el modelo, siempre que dicho conjunto de datos proporcione los valores para todas las variables predictoras.

### Ejemplo de uso del menú "Añadir predicciones a un conjunto de datos existente..."

Cargar los datos "Chile" como se describió anteriormente.

Para construir un modelo seleccione del menu de Rcmdr: "Estadisticos" -> "Ajuste de modelos" -> "Regresion lineal..." como "Variable explicada" seleccione income y age como "Variables explicativas" y pulse "Aceptar".

Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)
```{r include = TRUE, results = 'hide'}
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
```
y en la ventana de salida
```{r include = TRUE}
RegModel.1 <- lm(income~age, data=Chile)
summary(RegModel.1)
```

Obsérvese que el modelo se ha establecido a RegModel.1. Si se quiere predecir los valores para los ingresos (income) para los valores de edad (age) en el conjunto de datos Chile del menu "Modelos" de Rcmdr seleccione: "Predicir usando el modelo activo" -> "Anadir predicciones a un conjunto de datos existente...". En el diálogo seleccione un conjunto de datos compatible con el modelo. En este caso seleccione Chile. Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)
```{r include = TRUE, results = 'hide'}
Chile$fitted.RegModel.1 <- predict(RegModel.1, Chile)
```
y en la ventana de salida
```{r include = TRUE}
Chile$fitted.RegModel.1 <- predict(RegModel.1, Chile)
```

Las predicciones para ingreso (income) se han guardado como fitted.RegModel.1 en el conjunto de datos (Chile). 
Se pueden ver los valores añadidos usando el boton "Visualizar datos".

\name{ksMenu.es}
\title{Test de Kolmogorov-Smirnov}
\alias{Test de Kolmogorov-Smirnov (es)}
\docType{package}
\encoding{UTF-8}
\description{
  Dentro del menú "Estadísticos" -> "Test no paramétricos", se
  proporcionan una nueva entrada
  "Test de Kolmogorov-Smirnov para dos muestras..." para realizar el
  test de Kolmogorov-Smirnov para dos muestras, cuya hipótesis nula es
  que ambas muestras han sido extraídas de la misma distribución
  contínua. Esta opción usa la función \code{ks.test} del paquete
  \code{stats}. Para más información véase \code{\link[stats]{ks.test}}.
}

\details{
  Ejemplo de uso del menú "Test de Kolmogorov-Smirnov para dos muestras...".

  Cargar los datos "Baumann" eligiendo del menu de Rcmdr: "Datos" ->
  "Conjuntos de datos en paquetes" ->
  "Leer conjunto de datos desde paquete adjunto..." pulsar dos veces
  sobre "carData", pulsar sobre "Baumann" y sobre "Aceptar". Rcmdr
  responde con la siguiente instrucción en el cuadro de instrucciones (R
  Script)
  
  \code{data(Baumann, package="carData")}

  Para comparar las distribuiones de "pretest.1" y "post.test.1",
  seleccione del menú de Rcmdr: "Estadísticos" -> "Test no paramétricos"
  -> "Test de Kolmogorov-Smirnov para dos muestras..." seleccione
  "pretest.1" y "post.test.1", luego pulse "Aceptar". Rcmdr responde con
  la siguiente \enc{instrucción}{instruccion} en el cuadro de
  instrucciones (R Script)

  \code{with(Baumann, ks.test(pretest.1, post.test.1))}
}

\author{
  Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
  Para \enc{más}{mas} \enc{información}{informacion} \enc{véase}{vease} \code{\link[Rcmdr]{Rcmdr-package}}. 
}

\name{predictMenu.es}
\title{Opción de menú para hacer predicciones usando el modelo activo}
\alias{Menú predicciones (es)}
\docType{package}
\encoding{UTF-8}
\description{
  La entrada de menú "Predecir usando el modelo activo", en el menú
  modelos, tiene dos opciones para predecir datos usando el modelo
  activo dependiendo de cómo se proporcionen los valores para las variables predictoras.
  
  La primera entrada es "Introducir datos y predecir".
  Si selecciona esta opción, se creará un nuevo conjunto de datos, como
  un data.frame y se abrirá el editor automáticamente.
  A continuación, puede introducir los valores de la variable predictora
  que desea utilizar para la predicción, no es necesario introducir los
  valores de las variables no predictoras.
  Al cerrar el editor de datos se muestran los valores predichos.

  La segunda entrada de menú
  "Agregar predicciones a un conjunto de datos existente ..." permite
  agregar predicciones a un conjunto de datos existente que proporcione
  los datos valores para todas las variables predictoras.
  Después de seleccionar esta opción, el usuario o usuaria puede
  seleccionar un conjunto de datos existente utilizando el cuadro de
  diálogo correspondiente.

  Si el conjunto de datos no proporciona los valores para todas las
  variables predictoras, se producirá un error y no se proporcionarán
  valores predichos.

  A diferencia de la opción del menú
  "Añadir las estadísticas de las observaciones a los datos...", esta
  opción puede ser usada con un conjunto de datos distinto al que se ha
  utilizado para construir el modelo, siempre que dicho conjunto de
  datos proporcione los valores para todas las variables predictoras.
}

\details{
  Ejemplo de uso del menú "Introducir datos y predecir".

  Cargar los datos "Chile" eligiendo del menú de Rcmdr: "Datos" ->
  "Conjuntos de datos en paquetes" ->
  "Leer conjunto de datos desde paquete adjunto..." pulsar dos veces
  sobre "car", pulsar sobre "Chile" y sobre "Aceptar". Rcmdr responde con la siguiente instrucción en el cuadro de
  instrucciones (R Script)

  \code{data(Chile, package="car")}

  Para construir un modelo seleccione del menú de Rcmdr: "Estadísticos"
  -> "Ajuste de modelos" -> "Regresion lineal...". Como
  "Variable explicada" seleccione income y age como
  "Variables explicativas" y pulse "Aceptar". Rcmdr responde con la
  siguiente instrucción en el cuadro de instrucciones (R Script)

  \code{RegModel.1 <- lm(income~age, data=Chile)}

  \code{summary(RegModel.1)}

  Obsérvese que el modelo se ha establecido a RegModel.1. Si quiere
  predecir el ingreso (income) para personas de 35 y 40 años de edad
  (age). Del menú de Rcmdr seleccione: "Modelos" ->
  "Predecir usando el modelo activo" ->
  "Introducir datos y predecir". En la columna edad (age) introduzca 35
  y 40 y cierre el editor. Rcmdr responde con la siguiente instrucción
  en el cuadro de instrucciones (R Script)

  \code{.data <- edit(Chile[0,])}

  \code{.data}

  \code{predict(RegModel.1, .data)}

  \code{remove(.data)}

  Se muestra el valor predicho de ingresos para esas edades usando el modelo activo (RegModel.1)
  
  Ejemplo de uso del menú "Anadir predicciones a un conjunto de datos existente..."

  Cargar los datos "Chile" eligiendo del menú de Rcmdr: "Datos" ->
  "Conjuntos de datos en paquetes" ->
  "Leer conjunto de datos desde paquete adjunto..." pulsar dos veces
  sobre "car", pulsar sobre "Chile" y "Aceptar". Rcmdr responde con la siguiente instrucción en el cuadro de
  instrucciones (R Script)
  
  \code{data(Chile, package="car")}

  Para construir un modelo seleccione del menú de Rcmdr: "Estadísticos"
  -> "Ajuste de modelos" -> "Regresión lineal..." como
  "Variable explicada" seleccione income y age como
  "Variables explicativas" y pulse "Aceptar".

  Rcmdr responde con la siguiente instruccion en el cuadro de
  instrucciones (R Script)

  \code{RegModel.1 <- lm(income~age, data=Chile)}
  \code{summary(RegModel.1)}

  Obsérvese que el modelo se ha establecido a RegModel.1. Si se quiere
  predecir los valores para los ingresos (income) para los valores de
  edad (age) en el conjunto de datos Chile del menu "Modelos" de Rcmdr
  seleccione: "Predicir usando el modelo activo" ->
  "Anadir predicciones a un conjunto de datos existente...". En el
  diálogo seleccione un conjunto de datos compatible con el modelo. En
  este caso seleccione Chile. Rcmdr responde con la siguiente
  instrucción en el cuadro de instrucciones (R Script)

  \code{Chile$fitted <- predict(RegModel.1, Chile)}

  Las predicciones para ingreso (income) se han guardado como fitted en el conjunto de datos (Chile)
  }

\author{
Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
Para más información véase \code{\link[Rcmdr]{Rcmdr-package}}. 
}

\name{paretochartMenu.es}
\title{Opción de menú para hacer gráficos de Pareto}
\alias{Gráfico de Pareto (es)}
\docType{package}
\encoding{UTF-8}
\description{
  Dentro del menú "Control de Calidad" -> "Gráfica de Pareto", se proporcionan una nueva entrada para realizar un gráfico de Pareto en el que se representa una variable de tipo factor por orden decreciente de frecuencias.
  Esta gráfica se suele utilizar para identificar las causas más frecuentes de un fallo.
  Esta opción usa la función \code{paretochart} del paquete \code{qicharts2}.
  Para más información véase \code{\link[qicharts2]{paretochart}}.
}

\details{
  Ejemplo de uso del menú "Gráfica de Pareto".

  Cargar los datos "hospital_infections" eligiendo del menu de Rcmdr:
  "Datos" -> "Conjuntos de datos en paquetes" ->
  "Leer conjunto de datos desde paquete adjunto..." pulsar dos veces
  sobre "quicharts2", pulsar sobre "hospital_infections" y sobre
  "Aceptar". 
  Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)

  \code{data(hospital_infections, package="qicharts2")}

  Para construir el diagrama de Pareto de la variable "infection", seleccione
  del menú de Rcmdr: "Control de Calidad" -> "Gráfica de Pareto" seleccione
  "infection" y "Aceptar".
  Rcmdr responde con la siguiente instrucción en el cuadro de instrucciones (R Script)

  \code{with(hospital_infections, paretochart(infection))}

  y se obtiene el gráfico de Pareto en una nueva ventana.
}

\author{
  Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
  Para más información véase \code{\link[Rcmdr]{Rcmdr-package}}. 
}

\name{paretochartMenu}
\title{Menu option to make a Pareto chart}
\alias{paretochartMenu}
\alias{Pareto chart}
\docType{package}
\encoding{UTF-8}
\description{
  Within the menu "Quality Control" -> "Pareto Chart", a new entry is
  provided to make a Pareto chart in which a factor type variable is
  represented in decreasing order of frequencies.
  This graph is often used to identify the most common causes of a failure.
  This option uses the \code{paretochart} function from the \code{qicharts2} package.
  For more information see \code{\link[qicharts2]{paretochart}}.
}

\details{
  Here is an example of "Pareto chart" menu entry.

  Load data "hospital_infections" selecting from Rcmdr menu: "Data" ->
  "Data in packages" -> "Read data set from an attached package..." then
  double-click on "quicharts2", click on "hospital_infections" and on "OK". Rcmdr
  reply with the following command in source pane (R Script)

  \code{data(hospital_infections, package="qicharts2")}

  To build a Pareto chart on variable "infection", select from Rcmdr
  menu: "Quality Control" -> "Pareto chart" select "infection" and  "OK". Rcmdr reply with the following command in source pane (R Script)

  \code{with(hospital_infections, paretochart(infection))}

  and the graph is plotted in another window.
}


\author{
  Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
  For more information see \code{\link[Rcmdr]{Rcmdr-package}}. 

  Para ayuda en \enc{español}{espanol}, \enc{véase}{vease}
  \code{\link{Gráfico de Pareto (es)}}. (For Spanish help see
  \code{\link{Gráfico de Pareto (es)}}.) 
}

\name{sigmaMenu.es}
\title{Test de varianza}
\alias{Test de varianza (es)}
\docType{package}
\encoding{UTF-8}
\description{
  Dentro del menú "Estadísticos" -> "Varianzas", se proporcionan una nueva entrada para
  calcular intervalos de confianza y hacer contrastes sobre la varianza
  en una población normal. Esta opción usa la
  función \code{sigma.test} del paquete \code{TeachingDemos}. Para más
  información véase \code{\link[TeachingDemos]{sigma.test}}.
}

\details{
  Ejemplo de uso del menú "Test de varianza para una muestra...".

  Cargar los datos "sweetpotato" eligiendo del menu de Rcmdr: "Datos" ->
  "Conjuntos de datos en paquetes" ->
  "Leer conjunto de datos desde paquete adjunto..." pulsar dos veces
  sobre "randtests", pulsar sobre "sweetpotato" y sobre "Aceptar". Rcmdr responde con la siguiente instrucción en el cuadro de
  instrucciones (R Script)

  \code{data(sweetpotato, package="randtests")}

  \code{sweetpotato <- as.data.frame(sweetpotato)}

  Para construir el intervalo de confianza para sigma para la variable "yield", seleccione
  del menú de Rcmdr: "Estadísticos" -> "Varianzas" ->
  "Test de varianza para una muestra..." seleccione
  "yield" y "Aceptar". Rcmdr responde con la
  siguiente instruccion en el cuadro de instrucciones (R Script)

  \code{with(sweetpotato, sigma.test(yield[!is.na(yield)], alternative='two.sided', sigmasq=1.0, conf.level=0.95))}
}

\author{
Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
Para más información véase \code{\link[Rcmdr]{Rcmdr-package}}. 
}

\name{randomnessMenu.es}
\title{Test de aleatoriedad}
\alias{Test de aleatoriedad (es)}
\docType{package}
\encoding{UTF-8}
\description{
  Dentro del menú "Test no paramétricos" se proporcionan dos nuevas
  entradas para realizar el test de aleatoriedad.

  La primera "Test de aleatoriedad para un factor de dos niveles..." sirve para
  contrastar la aleatoriedad de una variable de tipo factor con dos
  niveles. Esta opción usa la función \code{runs.test} del paquete
  \code{tseries}. Para más información véase \code{\link[tseries]{runs.test}}.

  La segunda entrada del menú
  "Test de aleatoriedad para una variable numérica..." sirve para
  contrastar la aleatoriedad de una variable numérica. Esta opción usa
  la función \code{runs.test} del paquete \code{randtest}. Para más
  información véase \code{\link[randtests]{runs.test}}.
}

\details{
  Ejemplo de uso del menú
  "Test de aleatoriedad para un factor con dos niveles...".

  Cargar los datos "AMSsurvey" eligiendo del menu de Rcmdr: "Datos" ->
  "Conjuntos de datos en paquetes" ->
  "Leer conjunto de datos desde paquete adjunto..." pulsar dos veces
  sobre "car", pulsar sobre "AMSsurvey" y sobre "Aceptar". Rcmdr responde con la siguiente instruccion en el cuadro de
  instrucciones (R Script)

  \code{data(AMSsurvey, package="car")}

  Para hacer el test de aleatoriedad a la variable "sex", seleccione
  del menú de Rcmdr: "Estadísticos" -> "Test no paramétricos" ->
  "Test de aleatoriedad para un factor con dos niveles..." seleccione
  "sex" y "OK". Rcmdr responde con la
  siguiente instruccion en el cuadro de instrucciones (R Script)

  \code{with(AMSsurvey, twolevelfactor.runs.test(sex))}

  Ejemplo de uso del menú "Test de aleatoriedad para una variable numérica...".

  Cargar los datos "sweetpotato" eligiendo del menu de Rcmdr: "Datos" ->
  "Conjuntos de datos en paquetes" ->
  "Leer conjunto de datos desde paquete adjunto..." pulsar dos veces
  sobre "randtests", pulsar sobre "sweetpotato" y sobre "Aceptar". Rcmdr responde con la siguiente instruccion en el cuadro de
  instrucciones (R Script)

  \code{data(sweetpotato, package="randtests")}

  \code{sweetpotato <- as.data.frame(sweetpotato)}

  Para hacer el test de aleatoriedad a la variable "yield", seleccione
  del menú de Rcmdr: "Estadísticos" -> "Test no paramétricos" ->
  "Test de aleatoriedad para un factor con dos niveles..." seleccione
  "sex" y "OK". Rcmdr responde con la
  siguiente instruccion en el cuadro de instrucciones (R Script)

  \code{with(sweetpotato, numeric.runs.test(yield))}
}

\author{
Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
Para más información véase \code{\link[Rcmdr]{Rcmdr-package}}. 


For help in English see \code{\link{Randomness test}}. (Para ayuda en \enc{inglés}{ingles}, \enc{véase}{vease}
\code{\link{Randomness test}}.) 
}

\name{RcmdrPlugin.UCA.es}
\title{RcmdrPlugin.UCA.es: Algunas adaptaciones para Rcmdr hechas por el
  proyecto R-UCA}
\alias{RcmdrPlugin.UCA.es}
\docType{package}
\encoding{UTF-8}

\description{
  Algunas extensiones a Rcmdr (R Commander), test de aleatoriedad, test
  de varianza para una muestra normal y
  predicciones utilizando el modelo activo, para la \enc{enseñanza}{ensenanza} de
  un primer curso universitario en \enc{estadística}{estadistica} hechas por el
  proyecto R-UCA y usadas en la Universidad de \enc{Cádiz}{Cadiz} (UCA).

  Todas las adaptaciones \enc{serán}{seran} propuestas para su \enc{incorporación}{incorporacion} a
  Rcmdr. Las adaptaciones que se incorporen al paquete Rcmdr se \enc{suprimirán}{suprimiran}
  de este paquete.
}
\details{
\tabular{ll}{
Paquete: \tab RcmdrPlugin.UCA\cr
Tipo: \tab Paquete\cr
Version: \tab 5.1-2\cr
Fecha: \tab 2024-09-26\cr
Licencia: \tab GPL (>= 3)\cr
}
}

\examples{
# Se proporcionan ejemplos de uso en la ayuda de cada opcion de menú.
}

\author{
Manuel \enc{Muñoz-Márquez}{Munoz-Marquez} <manuel.munoz@uca.es>
}

\keyword{package}
\seealso{
Para \enc{más}{mas} \enc{información}{informacion} \enc{véase}{vease} \code{\link[Rcmdr]{Rcmdr-package}}.
}

\references{
[1] \url{http://knuth.uca.es/RcmdrPlugin.UCA/}
}

\name{RcmdrPlugin.UCA-internal}
\title{RcmdrPlugin.UCA: Some extension to Rcmdr (R Commander) made by
  R-UCA project and used in teaching statistics at University of Cadiz
  (UCA).}

\alias{browseRUCAWebsite}
\alias{browseRcmdrPluginUCA}
\alias{cchart1Menu}
\alias{cchart2Menu}
\alias{cchartpMenu}
\alias{checkRUCAversion}
\alias{input2predict}
\alias{npchart1Menu}
\alias{npchart2Menu}
\alias{npchartpMenu}
\alias{numeric.runs.test}
\alias{pchart1Menu}
\alias{pchart2Menu}
\alias{pchartpMenu}
\alias{predict4dataset}
\alias{R1mcMenu}
\alias{R2mcMenu}
\alias{RpmcMenu}
\alias{randomnessFTest}
\alias{randomnessNTest}
\alias{S1mcMenu}
\alias{S2mcMenu}
\alias{SpmcMenu}
\alias{SampleSizeZMenu}
\alias{sigma.test}
\alias{sigmaTest}
\alias{twolevelfactor.runs.test}
\alias{uchart1Menu}
\alias{uchart2Menu}
\alias{uchartpMenu}
\alias{xbar1mcMenu}
\alias{xbar2mcMenu}
\alias{xbarpmcMenu}
\alias{xbarone1Menu}

\encoding{UTF-8}
\description{Internal functions (should not be called by the user) for
  RcmdrPlugin.UCA packages. 
  For user information ask for help about \code{\link[RcmdrPlugin.UCA]{RcmdrPlugin.UCA}}.}
\keyword{internal}

\name{qccMenu.es}
\title{Opciones de menú para hacer gráficos de control de calidad}
\alias{Gráficos de control de calidad (es)}
\docType{package}
\encoding{UTF-8}
\description{
  Dentro del menú "Control de Calidad" se proporcionan nuevas entradas
  para realizar múltipes gráficos de control de calidad.
}

\details{
  Estas opciones usan la función \code{qcc} del paquete \code{qcc}.
  Para más información véase \code{\link[qcc]{qcc}}.
}

\author{
  Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
  Para más información véase \code{\link[qcc]{qcc}} y \code{\link[Rcmdr]{Rcmdr-package}}. 
}

\name{randomnessMenu}
\title{Randomness test}
\alias{Randomness test}
\docType{package}
\encoding{UTF-8}
\description{
  In the "Nonparametric Tests" menu, two new entries are provided to
  perform the randomness test.

  The first "Randomness test for two level factor..." can be used to
  contrast the randomness of a factor with two levels. This option use the function \code{runs.test} from
  \code{tseries} package. For more information see
  \code{\link[tseries]{runs.test}}.
  
  The second entry in the menu
  "Randomness test for numeric variable..." is used to test the
  randomness of a numerical variable. This option use the function \code{runs.test} from
  \code{randtest} package. For more information see \code{\link[randtests]{runs.test}}.
}

\details{
  Here is an example of "Randomness test for a two level factor..." menu
  entry.

  Load data "AMSsurvey" selecting from Rcmdr menu: "Data" ->
  "Data in packages" -> "Read data set from an attached package..." then
  double-click on "car", click on "AMSsurvey" and on "OK". Rcmdr reply
  with the following command in source pane (R Script)

  \code{data(AMSsurvey, package="car")}

  To make randomness test on variable "sex", select from Rcmdr menu:
  "Statistics" -> "Nonparametric tests" ->
  "Randomness test for two level factor..." select "sex" and "OK". Rcmdr
  reply with the following command in source pane (R Script)

  \code{with(AMSsurvey, twolevelfactor.runs.test(sex))}

  Here is an example of "Randomness test for a numeric variable..." menu
  entry.

  Load data "sweetpotato" selecting from Rcmdr menu: "Data" ->
  "Data in packages" -> "Read data set from an attached package..." then
  double-click on "randtests", click on "sweetpotato" and on "OK". Rcmdr
  reply with the following command in source pane (R Script)

  \code{data(sweetpotato, package="randtests")}

  \code{sweetpotato <- as.data.frame(sweetpotato)}

  To make randomness test on variable "yield", select from Rcmdr menu:
  "Statistics" -> "Nonparametric tests" ->
  "Randomness test for numeric variable..." select "yield" and
  "OK". Rcmdr reply with the following command in source pane (R Script)

  \code{with(sweetpotato, numeric.runs.test(yield))}
  }

\author{
Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
For more information see \code{\link[Rcmdr]{Rcmdr-package}}. 

Para ayuda en \enc{español}{espanol}, \enc{véase}{vease}
\code{\link{Test de aleatoriedad (es)}}. (For help in Spanish see \code{\link{Test de aleatoriedad (es)}}.) 
}

\name{qccMenu}
\title{Menu options to make a quality control graphs}
\alias{qccMenu}
\alias{Quality control graphs}

\alias{c-chart}
\alias{np-chart}
\alias{p-chart}
\alias{R-chart}
\alias{S-chart}
\alias{u-chart}
\alias{xbar-chart}

\docType{package}
\encoding{UTF-8}
\description{
  Within the menu "Quality Control" new entries are provided to make mutiple
  quality control graphs.}

\details{
  These options use the \code{qcc} function from the \code{qcc} package.
  For more information see \code{\link[qcc]{qcc}}.
}

\author{
  Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
  For more information see \code{\link[qcc]{qcc}} and \code{\link[Rcmdr]{Rcmdr-package}}. 

  Para ayuda en \enc{español}{espanol}, \enc{véase}{vease}
  \code{\link{Gráficos de control de calidad (es)}}. (For Spanish help see
  \code{\link{Gráficos de control de calidad (es)}}.) 
}

\name{ksMenu}
\title{Kolmogorov-Smirnov test}
\alias{Kolmogorov-Smirnov test}
\docType{package}
\encoding{UTF-8}
\description{
  Within the "Statistics" -> "Non-parametric test" menu, a new entry is
  provided "Kolmogorov-Smirnov test for two samples..." to carry out a
  Kolmogorov-Smirnov test, a two-sample test of the null hypothesis that
  both samples were drawn from the same continuous distribution. This
  option uses the function \code{ks.test} of the package
  \code{stats}. For more information see \code{\link[stats]{ks.test}}.
}

\details{
  Here is an example of "Kolmogorov-Smirnov test for two samples..." menu entry.

  Load data "Baumann" selecting from Rcmdr menu: "Data" ->
  "Data in packages" -> "Read data set from an attached package..." then
  double-click on "carData", click on "Baumann" and on "OK". Rcmdr reply
  with the following command in source pane (R Script)

  \code{data(Baumann, package="carData")}

  To compare the distributions of "pretest.1" with "post.test.1", select
  from Rcmdr menu: "Statistics" -> "Non-parametric test" ->
  "Kolmogorov-Smirnov test for two samples..." select "pretest.1" and
  "post.test.1", then "OK". Rcmdr reply with the following command in
  source pane (R Script)
  
  \code{with(Baumann, ks.test(pretest.1, post.test.1))}
  }

\author{
Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
For more information see \code{\link[Rcmdr]{Rcmdr-package}}. 

Para ayuda en \enc{español}{espanol}, \enc{véase}{vease}
\code{\link{Test de Kolmogorov-Smirnov (es)}}. (For Spanish help see \code{\link{Test de Kolmogorov-Smirnov (es)}}.) 
}

\name{RcmdrPlugin.UCA-package}
\title{RcmdrPlugin.UCA: Some customization to Rcmdr made by R-UCA project}
\alias{RcmdrPlugin.UCA-package}
\alias{RcmdrPlugin.UCA}
\docType{package}
\encoding{UTF-8}
\description{
  Some extension to Rcmdr (R Commander), randomness test, variance test
  for one normal sample and predictions using active model, to teach statistics in a first
  university course made by R-UCA project and used at University of
  Cadiz (UCA).

  All the customizations provides by this package will be propose to be
  part of the Rcmdr package. 
  All the customization included in the Rcmdr package will be dropped from here.  
}
\details{
\tabular{ll}{
Package: \tab RcmdrPlugin.UCA\cr
Type: \tab Package\cr
Version: \tab 5.1-2\cr
Date: \tab 2024-09-26\cr
License: \tab GPL version 3 or newer\cr
}
}

\examples{
# Examples of use are provided in the help of each option of menu.
}

\author{
Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}
\seealso{
For more information see \code{\link[Rcmdr]{Rcmdr-package}}. 

Para ayuda en \enc{español}{espanol}, \enc{véase}{vease}
\code{\link{RcmdrPlugin.UCA.es}}. (For Spanish help see \code{\link{RcmdrPlugin.UCA.es}}.) 
}

\references{
[1] \url{http://knuth.uca.es/RcmdrPlugin.UCA/}
}

\name{predictMenu}
\title{Menu option to make predictions using active model}
\alias{Predict menu}
\docType{package}
\encoding{UTF-8}
\description{
  The menu entry "Predict using active model", in models menu, has two
  options to predict data using active model depending on how the data
  for predictor variables will be provided.
  
  The first entry is "Input data and predict".
  If you select this option a new data set, as a data.frame, will be created and the
  editor will be invoked.
  Then you can entry the values of the predictor variable that you want
  to use for prediction, the values for non predictor variables are not
  required.
  When you close the data editor the predicted values for predicted
  variable are shown. 

  The second menu entry "Add predictions to existing dataset..." allows
  to us to add predictions to existing dataset that provides the data
  values for all predictor variables.
  After selecting this option, the user can select an existing data set
  using dialog box.

  If the data set does not provides the values for all predicting
  variables an error will occur and no predicted values will be
  provided.

  Unlike the menu option "Add observation statistics to data...", this
  option can be used with a different data set than the one used to
  construct the model, if that dataset provides the values for all the
  predictor variables.
}

\details{
  Here is an example of use of "Input data and predict" menu entry.

  Load data "Chile" selecting from Rcmdr menu: "Data" ->
  "Data in packages" -> "Read data set from an attached package..." then
  double-click on "car", click on "Chile" and on "OK".

  Rcmdr reply with the following command in source pane (R Script)

  \code{data(Chile, package="car")}

  To build a model select from Rcmdr menu: "Statistics" -> "Model fit"
  -> "Linear Regresion...". As "Response variable" select income and age
  as "Explanatory variables" and click on "OK". Rcmdr reply with the
  following command in source pane (R Script)

  \code{RegModel.1 <- lm(income~age, data=Chile)}
  
  \code{summary(RegModel.1)}

  Note that the active model is set to RegModel.1. So if you want to
  predict a new value for a 35 and 40 age person. Select from Rcmdr
  menu: "Models" -> "Predict using active model" ->
  "Input data and predict". In age column input 35 and 40 and then close
  the editor. Rcmdr reply with the following command in source pane (R
  Script)

  \code{.data <- edit(Chile[0,])}

  \code{.data}

  \code{predict(RegModel.1, .data)}

  \code{remove(.data)}

  And output the predicted value of income for that age using active model (RegModel.1)
  
  Here is an example of use of "Add predictions to existing dataset..."
  menu entry.
  
  Load data "Chile" selecting from Rcmdr menu: "Data" ->
  "Data in packages" -> "Read data set from an attached package..." then
  double-click on "car", click on "Chile" and "OK".
  
  Rcmdr reply with the following command in source pane (R Script)
  
  \code{data(Chile, package="car")}
  
  To build a model select from Rcmdr menu: "Statistics" -> "Model fit"
  -> "Linear Regresion..." as "Response variable" select income and age
  as "Explanatory variables" and click on "OK".
  Rcmdr reply with the following command in source pane (R Script)
  
  \code{RegModel.1 <- lm(income~age, data=Chile)}

  \code{summary(RegModel.1)}
  
  Note that the active model is set to RegModel.1
  So if you want to predict the values for income for age data in Chile
  dataset. Select from Rcmdr menu: "Models" ->
  "Predict using active model" ->
  "Add predictions to existing dataset...".
  In the dialog select a compatible dataset with the model. In this case
  select Chile. Rcmdr reply with the following command in source pane (R
  Script)
  
  \code{Chile$fitted <- predict(RegModel.1, Chile)}
  
  The predicted value of income has been saved as fitted in the selected dataset (Chile)
  }

\author{
Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
For more information see \code{\link[Rcmdr]{Rcmdr-package}}. 

Para ayuda en \enc{español}{espanol}, \enc{véase}{vease}
\code{\link{Menú predicciones (es)}}. (For Spanish help see \code{\link{Menú predicciones (es)}}.) 
}

\name{sigmaMenu}
\title{Variance test}
\alias{Variance test}
\docType{package}
\encoding{UTF-8}
\description{
  Within the "Statistics" -> "Variances" menu, a new entry is provided for calculate
  confidence intervals and make contrasts on variance in a normal
  population. This option uses the function \code{sigma.test} of the
  package \code{TeachingDemos}. For more information see \code{\link[TeachingDemos]{sigma.test}}.
}

\details{
  Here is an example of "Single-Sample Variance Test..." menu entry.

  Load data "sweetpotato" selecting from Rcmdr menu: "Data" ->
  "Data in packages" -> "Read data set from an attached package..." then
  double-click on "randtests", click on "sweetpotato" and on "OK". Rcmdr
  reply with the following command in source pane (R Script)

  \code{data(sweetpotato, package="randtests")}

  \code{sweetpotato <- as.data.frame(sweetpotato)}

  To build a confidence interval for sigma on variable "yield", select from Rcmdr menu: "Statistics" -> "Variances" -> "Single-sample Variance Test..." select "yield" and  "OK". Rcmdr reply with the following command in source pane (R Script)

  \code{with(sweetpotato, sigma.test(yield[!is.na(yield)], alternative='two.sided', sigmasq=1.0, conf.level=0.95))}
  }

\author{
Manuel Munoz-Marquez <manuel.munoz@uca.es>
}

\keyword{package}

\seealso{
For more information see \code{\link[Rcmdr]{Rcmdr-package}}. 

Para ayuda en \enc{español}{espanol}, \enc{véase}{vease}
\code{\link{Test de varianza (es)}}. (For Spanish help see \code{\link{Test de varianza (es)}}.) 
}
